# Generated from russian.sbl by Snowball 3.1.1 - https://snowballstem.org/

from .basestemmer import BaseStemmer
from .among import Among


class RussianStemmer(BaseStemmer):
    '''
    This class implements the stemming algorithm defined by a snowball script.
    Generated from russian.sbl by Snowball 3.1.1 - https://snowballstem.org/
    '''

    g_v = {"а", "е", "и", "о", "у", "ы", "э", "ю", "я"}

    I_p2 = 0
    I_pV = 0

    def __r_mark_regions(self):
        self.I_pV = self.limit
        self.I_p2 = self.limit
        v_1 = self.cursor
        try:
            if not self.go_out_grouping(RussianStemmer.g_v):
                raise lab0()
            self.cursor += 1
            self.I_pV = self.cursor
            if not self.go_in_grouping(RussianStemmer.g_v):
                raise lab0()
            self.cursor += 1
            if not self.go_out_grouping(RussianStemmer.g_v):
                raise lab0()
            self.cursor += 1
            if not self.go_in_grouping(RussianStemmer.g_v):
                raise lab0()
            self.cursor += 1
            self.I_p2 = self.cursor
        except lab0: pass
        self.cursor = v_1
        return True

    def __r_perfective_gerund(self):
        self.ket = self.cursor
        among_var = self.find_among_b(RussianStemmer.a_0)
        if among_var == 0:
            return False
        self.bra = self.cursor
        if among_var == 1:
            while True:
                try:
                    if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "а":
                        raise lab0()
                    self.cursor -= 1
                    break
                except lab0: pass
                if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "я":
                    return False
                self.cursor -= 1
                break
            self.slice_del()
        else:
            self.slice_del()
        return True

    def __r_adjective(self):
        self.ket = self.cursor
        if self.find_among_b(RussianStemmer.a_1) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        return True

    def __r_adjectival(self):
        if not self.__r_adjective():
            return False
        v_1 = self.limit - self.cursor
        try:
            self.ket = self.cursor
            among_var = self.find_among_b(RussianStemmer.a_2)
            if among_var == 0:
                self.cursor = self.limit - v_1
                raise lab0()
            self.bra = self.cursor
            if among_var == 1:
                while True:
                    try:
                        if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "а":
                            raise lab1()
                        self.cursor -= 1
                        break
                    except lab1: pass
                    if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "я":
                        self.cursor = self.limit - v_1
                        raise lab0()
                    self.cursor -= 1
                    break
                self.slice_del()
            else:
                self.slice_del()
        except lab0: pass
        return True

    def __r_reflexive(self):
        self.ket = self.cursor
        if self.find_among_b(RussianStemmer.a_3) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        return True

    def __r_verb(self):
        self.ket = self.cursor
        among_var = self.find_among_b(RussianStemmer.a_4)
        if among_var == 0:
            return False
        self.bra = self.cursor
        if among_var == 1:
            while True:
                try:
                    if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "а":
                        raise lab0()
                    self.cursor -= 1
                    break
                except lab0: pass
                if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "я":
                    return False
                self.cursor -= 1
                break
            self.slice_del()
        else:
            self.slice_del()
        return True

    def __r_noun(self):
        self.ket = self.cursor
        if self.find_among_b(RussianStemmer.a_5) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        return True

    def __r_derivational(self):
        self.ket = self.cursor
        if self.find_among_b(RussianStemmer.a_6) == 0:
            return False
        self.bra = self.cursor
        if self.I_p2 > self.cursor:
            return False
        self.slice_del()
        return True

    def __r_tidy_up(self):
        self.ket = self.cursor
        among_var = self.find_among_b(RussianStemmer.a_7)
        if among_var == 0:
            return False
        self.bra = self.cursor
        if among_var == 1:
            self.slice_del()
            self.ket = self.cursor
            if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "н":
                return False
            self.cursor -= 1
            self.bra = self.cursor
            if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "н":
                return False
            self.cursor -= 1
            self.slice_del()
        elif among_var == 2:
            if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "н":
                return False
            self.cursor -= 1
            self.slice_del()
        else:
            self.slice_del()
        return True

    def _stem(self):
        v_1 = self.cursor
        try:
            while True:
                v_2 = self.cursor
                try:
                    while True:
                        v_3 = self.cursor
                        try:
                            self.bra = self.cursor
                            if self.cursor == self.limit or self.current[self.cursor] != "ё":
                                raise lab2()
                            self.cursor += 1
                            self.ket = self.cursor
                            self.cursor = v_3
                            break
                        except lab2: pass
                        self.cursor = v_3
                        if self.cursor >= self.limit:
                            raise lab1()
                        self.cursor += 1
                    self.slice_from("е")
                    continue
                except lab1: pass
                self.cursor = v_2
                break
        except lab0: pass
        self.cursor = v_1
        self.__r_mark_regions()
        self.limit_backward = self.cursor
        self.cursor = self.limit
        if self.cursor < self.I_pV:
            return False
        v_5 = self.limit_backward
        self.limit_backward = self.I_pV
        v_6 = self.limit - self.cursor
        try:
            while True:
                v_7 = self.limit - self.cursor
                try:
                    if not self.__r_perfective_gerund():
                        raise lab1()
                    break
                except lab1: pass
                self.cursor = self.limit - v_7
                v_8 = self.limit - self.cursor
                try:
                    if not self.__r_reflexive():
                        self.cursor = self.limit - v_8
                        raise lab1()
                except lab1: pass
                while True:
                    v_9 = self.limit - self.cursor
                    try:
                        if not self.__r_adjectival():
                            raise lab1()
                        break
                    except lab1: pass
                    self.cursor = self.limit - v_9
                    try:
                        if not self.__r_verb():
                            raise lab1()
                        break
                    except lab1: pass
                    self.cursor = self.limit - v_9
                    if not self.__r_noun():
                        raise lab0()
                    break
                break
        except lab0: pass
        self.cursor = self.limit - v_6
        v_10 = self.limit - self.cursor
        try:
            self.ket = self.cursor
            if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "и":
                self.cursor = self.limit - v_10
                raise lab0()
            self.cursor -= 1
            self.bra = self.cursor
            self.slice_del()
        except lab0: pass
        v_11 = self.limit - self.cursor
        self.__r_derivational()
        self.cursor = self.limit - v_11
        v_12 = self.limit - self.cursor
        self.__r_tidy_up()
        self.cursor = self.limit - v_12
        self.limit_backward = v_5
        self.cursor = self.limit_backward
        return True

    a_0 = [
        Among("в", -1, 1),
        Among("ив", 0, 2),
        Among("ыв", 0, 2),
        Among("вши", -1, 1),
        Among("ивши", 3, 2),
        Among("ывши", 3, 2),
        Among("вшись", -1, 1),
        Among("ившись", 6, 2),
        Among("ывшись", 6, 2)
    ]

    a_1 = [
        Among("ее", -1, 1),
        Among("ие", -1, 1),
        Among("ое", -1, 1),
        Among("ые", -1, 1),
        Among("ими", -1, 1),
        Among("ыми", -1, 1),
        Among("ей", -1, 1),
        Among("ий", -1, 1),
        Among("ой", -1, 1),
        Among("ый", -1, 1),
        Among("ем", -1, 1),
        Among("им", -1, 1),
        Among("ом", -1, 1),
        Among("ым", -1, 1),
        Among("его", -1, 1),
        Among("ого", -1, 1),
        Among("ему", -1, 1),
        Among("ому", -1, 1),
        Among("их", -1, 1),
        Among("ых", -1, 1),
        Among("ею", -1, 1),
        Among("ою", -1, 1),
        Among("ую", -1, 1),
        Among("юю", -1, 1),
        Among("ая", -1, 1),
        Among("яя", -1, 1)
    ]

    a_2 = [
        Among("ем", -1, 1),
        Among("нн", -1, 1),
        Among("вш", -1, 1),
        Among("ивш", 2, 2),
        Among("ывш", 2, 2),
        Among("щ", -1, 1),
        Among("ющ", 5, 1),
        Among("ующ", 6, 2)
    ]

    a_3 = [
        Among("сь", -1, 1),
        Among("ся", -1, 1)
    ]

    a_4 = [
        Among("ла", -1, 1),
        Among("ила", 0, 2),
        Among("ыла", 0, 2),
        Among("на", -1, 1),
        Among("ена", 3, 2),
        Among("ете", -1, 1),
        Among("ите", -1, 2),
        Among("йте", -1, 1),
        Among("ейте", 7, 2),
        Among("уйте", 7, 2),
        Among("ли", -1, 1),
        Among("или", 10, 2),
        Among("ыли", 10, 2),
        Among("й", -1, 1),
        Among("ей", 13, 2),
        Among("уй", 13, 2),
        Among("л", -1, 1),
        Among("ил", 16, 2),
        Among("ыл", 16, 2),
        Among("ем", -1, 1),
        Among("им", -1, 2),
        Among("ым", -1, 2),
        Among("н", -1, 1),
        Among("ен", 22, 2),
        Among("ло", -1, 1),
        Among("ило", 24, 2),
        Among("ыло", 24, 2),
        Among("но", -1, 1),
        Among("ено", 27, 2),
        Among("нно", 27, 1),
        Among("ет", -1, 1),
        Among("ует", 30, 2),
        Among("ит", -1, 2),
        Among("ыт", -1, 2),
        Among("ют", -1, 1),
        Among("уют", 34, 2),
        Among("ят", -1, 2),
        Among("ны", -1, 1),
        Among("ены", 37, 2),
        Among("ть", -1, 1),
        Among("ить", 39, 2),
        Among("ыть", 39, 2),
        Among("ешь", -1, 1),
        Among("ишь", -1, 2),
        Among("ю", -1, 2),
        Among("ую", 44, 2)
    ]

    a_5 = [
        Among("а", -1, 1),
        Among("ев", -1, 1),
        Among("ов", -1, 1),
        Among("е", -1, 1),
        Among("ие", 3, 1),
        Among("ье", 3, 1),
        Among("и", -1, 1),
        Among("еи", 6, 1),
        Among("ии", 6, 1),
        Among("ами", 6, 1),
        Among("ями", 6, 1),
        Among("иями", 10, 1),
        Among("й", -1, 1),
        Among("ей", 12, 1),
        Among("ией", 13, 1),
        Among("ий", 12, 1),
        Among("ой", 12, 1),
        Among("ам", -1, 1),
        Among("ем", -1, 1),
        Among("ием", 18, 1),
        Among("ом", -1, 1),
        Among("ям", -1, 1),
        Among("иям", 21, 1),
        Among("о", -1, 1),
        Among("у", -1, 1),
        Among("ах", -1, 1),
        Among("ях", -1, 1),
        Among("иях", 26, 1),
        Among("ы", -1, 1),
        Among("ь", -1, 1),
        Among("ю", -1, 1),
        Among("ию", 30, 1),
        Among("ью", 30, 1),
        Among("я", -1, 1),
        Among("ия", 33, 1),
        Among("ья", 33, 1)
    ]

    a_6 = [
        Among("ост", -1, 1),
        Among("ость", -1, 1)
    ]

    a_7 = [
        Among("ейше", -1, 1),
        Among("н", -1, 2),
        Among("ейш", -1, 1),
        Among("ь", -1, 3)
    ]


class lab0(BaseException): pass


class lab1(BaseException): pass


class lab2(BaseException): pass



# Generated from irish.sbl by Snowball 3.1.1 - https://snowballstem.org/

from .basestemmer import BaseStemmer
from .among import Among


class IrishStemmer(BaseStemmer):
    '''
    This class implements the stemming algorithm defined by a snowball script.
    Generated from irish.sbl by Snowball 3.1.1 - https://snowballstem.org/
    '''

    g_v = {"a", "e", "i", "o", "u", "á", "é", "í", "ó", "ú"}

    I_p2 = 0
    I_p1 = 0
    I_pV = 0

    def __r_mark_regions(self):
        self.I_pV = self.limit
        self.I_p1 = self.limit
        self.I_p2 = self.limit
        v_1 = self.cursor
        try:
            if not self.go_out_grouping(IrishStemmer.g_v):
                raise lab0()
            self.cursor += 1
            self.I_pV = self.cursor
            if not self.go_in_grouping(IrishStemmer.g_v):
                raise lab0()
            self.cursor += 1
            self.I_p1 = self.cursor
            if not self.go_out_grouping(IrishStemmer.g_v):
                raise lab0()
            self.cursor += 1
            if not self.go_in_grouping(IrishStemmer.g_v):
                raise lab0()
            self.cursor += 1
            self.I_p2 = self.cursor
        except lab0: pass
        self.cursor = v_1
        return True

    def __r_initial_morph(self):
        self.bra = self.cursor
        among_var = self.find_among(IrishStemmer.a_0)
        if among_var == 0:
            return False
        self.ket = self.cursor
        self.slice_from(IrishStemmer.as_0[among_var - 1])
        return True

    def __r_R1(self):
        return self.I_p1 <= self.cursor

    def __r_R2(self):
        return self.I_p2 <= self.cursor

    def __r_noun_sfx(self):
        self.ket = self.cursor
        among_var = self.find_among_b(IrishStemmer.a_1)
        if among_var == 0:
            return False
        self.bra = self.cursor
        if among_var == 1:
            if not self.__r_R1():
                return False
            self.slice_del()
        else:
            if not self.__r_R2():
                return False
            self.slice_del()
        return True

    def __r_deriv(self):
        self.ket = self.cursor
        among_var = self.find_among_b(IrishStemmer.a_2)
        if among_var == 0:
            return False
        self.bra = self.cursor
        if among_var == 1:
            if not self.__r_R2():
                return False
            self.slice_del()
        elif among_var == 2:
            self.slice_from("arc")
        elif among_var == 3:
            self.slice_from("gin")
        elif among_var == 4:
            self.slice_from("graf")
        elif among_var == 5:
            self.slice_from("paite")
        else:
            self.slice_from("óid")
        return True

    def __r_verb_sfx(self):
        self.ket = self.cursor
        among_var = self.find_among_b(IrishStemmer.a_3)
        if among_var == 0:
            return False
        self.bra = self.cursor
        if among_var == 1:
            if self.I_pV > self.cursor:
                return False
            self.slice_del()
        else:
            if not self.__r_R1():
                return False
            self.slice_del()
        return True

    def _stem(self):
        v_1 = self.cursor
        self.__r_initial_morph()
        self.cursor = v_1
        self.__r_mark_regions()
        self.limit_backward = self.cursor
        self.cursor = self.limit
        v_2 = self.limit - self.cursor
        self.__r_noun_sfx()
        self.cursor = self.limit - v_2
        v_3 = self.limit - self.cursor
        self.__r_deriv()
        self.cursor = self.limit - v_3
        v_4 = self.limit - self.cursor
        self.__r_verb_sfx()
        self.cursor = self.limit - v_4
        self.cursor = self.limit_backward
        return True

    a_0 = [
        Among("b'", -1, 1),
        Among("bh", -1, 4),
        Among("bhf", 1, 2),
        Among("bp", -1, 8),
        Among("ch", -1, 5),
        Among("d'", -1, 1),
        Among("d'fh", 5, 2),
        Among("dh", -1, 6),
        Among("dt", -1, 9),
        Among("fh", -1, 2),
        Among("gc", -1, 5),
        Among("gh", -1, 7),
        Among("h-", -1, 1),
        Among("m'", -1, 1),
        Among("mb", -1, 4),
        Among("mh", -1, 10),
        Among("n-", -1, 1),
        Among("nd", -1, 6),
        Among("ng", -1, 7),
        Among("ph", -1, 8),
        Among("sh", -1, 3),
        Among("t-", -1, 1),
        Among("th", -1, 9),
        Among("ts", -1, 3)
    ]
    as_0 = ("", "f", "s", "b", "c", "d", "g", "p", "t", "m")

    a_1 = [
        Among("íochta", -1, 1),
        Among("aíochta", 0, 1),
        Among("ire", -1, 2),
        Among("aire", 2, 2),
        Among("abh", -1, 1),
        Among("eabh", 4, 1),
        Among("ibh", -1, 1),
        Among("aibh", 6, 1),
        Among("amh", -1, 1),
        Among("eamh", 8, 1),
        Among("imh", -1, 1),
        Among("aimh", 10, 1),
        Among("íocht", -1, 1),
        Among("aíocht", 12, 1),
        Among("irí", -1, 2),
        Among("airí", 14, 2)
    ]

    a_2 = [
        Among("óideacha", -1, 6),
        Among("patacha", -1, 5),
        Among("achta", -1, 1),
        Among("arcachta", 2, 2),
        Among("eachta", 2, 1),
        Among("grafaíochta", -1, 4),
        Among("paite", -1, 5),
        Among("ach", -1, 1),
        Among("each", 7, 1),
        Among("óideach", 8, 6),
        Among("gineach", 8, 3),
        Among("patach", 7, 5),
        Among("grafaíoch", -1, 4),
        Among("pataigh", -1, 5),
        Among("óidigh", -1, 6),
        Among("achtúil", -1, 1),
        Among("eachtúil", 15, 1),
        Among("gineas", -1, 3),
        Among("ginis", -1, 3),
        Among("acht", -1, 1),
        Among("arcacht", 19, 2),
        Among("eacht", 19, 1),
        Among("grafaíocht", -1, 4),
        Among("arcachtaí", -1, 2),
        Among("grafaíochtaí", -1, 4)
    ]

    a_3 = [
        Among("imid", -1, 1),
        Among("aimid", 0, 1),
        Among("ímid", -1, 1),
        Among("aímid", 2, 1),
        Among("adh", -1, 2),
        Among("eadh", 4, 2),
        Among("faidh", -1, 1),
        Among("fidh", -1, 1),
        Among("áil", -1, 2),
        Among("ain", -1, 2),
        Among("tear", -1, 2),
        Among("tar", -1, 2)
    ]


class lab0(BaseException): pass



# Generated from finnish.sbl by Snowball 3.1.1 - https://snowballstem.org/

from .basestemmer import BaseStemmer
from .among import Among


class FinnishStemmer(BaseStemmer):
    '''
    This class implements the stemming algorithm defined by a snowball script.
    Generated from finnish.sbl by Snowball 3.1.1 - https://snowballstem.org/
    '''

    g_AEI = {"a", "e", "i", "ä"}

    g_C = {"b", "c", "d", "f", "g", "h", "j", "k", "l", "m", "n", "p", "q", "r", "s", "t", "v", "w", "x", "z"}

    g_v = {"a", "e", "i", "o", "u", "y", "ä", "ö"}

    g_particle_end = {"a", "e", "i", "n", "o", "t", "u", "y", "ä", "ö"}

    B_ending_removed = False
    I_p2 = 0
    I_p1 = 0

    def __r_mark_regions(self):
        self.I_p1 = self.limit
        self.I_p2 = self.limit
        if not self.go_out_grouping(FinnishStemmer.g_v):
            return False
        self.cursor += 1
        if not self.go_in_grouping(FinnishStemmer.g_v):
            return False
        self.cursor += 1
        self.I_p1 = self.cursor
        if not self.go_out_grouping(FinnishStemmer.g_v):
            return False
        self.cursor += 1
        if not self.go_in_grouping(FinnishStemmer.g_v):
            return False
        self.cursor += 1
        self.I_p2 = self.cursor
        return True

    def __r_particle_etc(self):
        if self.cursor < self.I_p1:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_p1
        self.ket = self.cursor
        among_var = self.find_among_b(FinnishStemmer.a_0)
        if among_var == 0:
            self.limit_backward = v_2
            return False
        self.bra = self.cursor
        self.limit_backward = v_2
        if among_var == 1:
            if not self.in_grouping_b(FinnishStemmer.g_particle_end):
                return False
        else:
            if self.I_p2 > self.cursor:
                return False
        self.slice_del()
        return True

    def __r_possessive(self):
        if self.cursor < self.I_p1:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_p1
        self.ket = self.cursor
        among_var = self.find_among_b(FinnishStemmer.a_4)
        if among_var == 0:
            self.limit_backward = v_2
            return False
        self.bra = self.cursor
        self.limit_backward = v_2
        if among_var == 1:
            try:
                if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "k":
                    raise lab0()
                self.cursor -= 1
                return False
            except lab0: pass
            self.slice_del()
        elif among_var == 2:
            self.slice_del()
            self.ket = self.cursor
            if not self.eq_s_b("kse"):
                return False
            self.bra = self.cursor
            self.slice_from("ksi")
        elif among_var == 3:
            self.slice_del()
        elif among_var == 4:
            if self.find_among_b(FinnishStemmer.a_1) == 0:
                return False
            self.slice_del()
        elif among_var == 5:
            if self.find_among_b(FinnishStemmer.a_2) == 0:
                return False
            self.slice_del()
        else:
            if self.find_among_b(FinnishStemmer.a_3) == 0:
                return False
            self.slice_del()
        return True

    def __r_LV(self):
        return self.find_among_b(FinnishStemmer.a_5) != 0

    def __r_VI(self):
        return self.find_among_b(FinnishStemmer.a_6) != 0

    def __r_A(self):
        while True:
            try:
                if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "a":
                    raise lab0()
                self.cursor -= 1
                break
            except lab0: pass
            if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "'":
                return False
            self.cursor -= 1
            break
        return True

    def __r_E(self):
        while True:
            try:
                if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "e":
                    raise lab0()
                self.cursor -= 1
                break
            except lab0: pass
            if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "'":
                return False
            self.cursor -= 1
            break
        return True

    def __r_I(self):
        while True:
            try:
                if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "i":
                    raise lab0()
                self.cursor -= 1
                break
            except lab0: pass
            if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "'":
                return False
            self.cursor -= 1
            break
        return True

    def __r_O(self):
        while True:
            try:
                if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "o":
                    raise lab0()
                self.cursor -= 1
                break
            except lab0: pass
            if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "'":
                return False
            self.cursor -= 1
            break
        return True

    def __r_U(self):
        while True:
            try:
                if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "u":
                    raise lab0()
                self.cursor -= 1
                break
            except lab0: pass
            if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "'":
                return False
            self.cursor -= 1
            break
        return True

    def __r_A_(self):
        while True:
            try:
                if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "ä":
                    raise lab0()
                self.cursor -= 1
                break
            except lab0: pass
            if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "'":
                return False
            self.cursor -= 1
            break
        return True

    def __r_O_(self):
        while True:
            try:
                if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "ö":
                    raise lab0()
                self.cursor -= 1
                break
            except lab0: pass
            try:
                if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "ø":
                    raise lab0()
                self.cursor -= 1
                break
            except lab0: pass
            if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "'":
                return False
            self.cursor -= 1
            break
        return True

    def __r_case_ending(self):
        if self.cursor < self.I_p1:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_p1
        self.ket = self.cursor
        among_var = self.find_among_b(FinnishStemmer.a_7)
        if among_var == 0:
            self.limit_backward = v_2
            return False
        self.bra = self.cursor
        self.limit_backward = v_2
        if among_var == 1:
            v_3 = self.limit - self.cursor
            try:
                v_4 = self.limit - self.cursor
                while True:
                    v_5 = self.limit - self.cursor
                    try:
                        if not self.__r_LV():
                            raise lab1()
                        break
                    except lab1: pass
                    self.cursor = self.limit - v_5
                    if not self.eq_s_b("ie"):
                        self.cursor = self.limit - v_3
                        raise lab0()
                    break
                self.cursor = self.limit - v_4
                if self.cursor <= self.limit_backward:
                    self.cursor = self.limit - v_3
                    raise lab0()
                self.cursor -= 1
                self.bra = self.cursor
            except lab0: pass
        elif among_var == 2:
            if not self.in_grouping_b(FinnishStemmer.g_v):
                return False
            if not self.in_grouping_b(FinnishStemmer.g_C):
                return False
        elif among_var == 3:
            if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "e":
                return False
            self.cursor -= 1
        self.slice_del()
        self.B_ending_removed = True
        return True

    def __r_other_endings(self):
        if self.cursor < self.I_p2:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_p2
        self.ket = self.cursor
        among_var = self.find_among_b(FinnishStemmer.a_8)
        if among_var == 0:
            self.limit_backward = v_2
            return False
        self.bra = self.cursor
        self.limit_backward = v_2
        if among_var == 1:
            try:
                if not self.eq_s_b("po"):
                    raise lab0()
                return False
            except lab0: pass
        self.slice_del()
        return True

    def __r_i_plural(self):
        if self.cursor < self.I_p1:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_p1
        self.ket = self.cursor
        if self.find_among_b(FinnishStemmer.a_9) == 0:
            self.limit_backward = v_2
            return False
        self.bra = self.cursor
        self.limit_backward = v_2
        self.slice_del()
        return True

    def __r_t_plural(self):
        if self.cursor < self.I_p1:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_p1
        self.ket = self.cursor
        if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "t":
            self.limit_backward = v_2
            return False
        self.cursor -= 1
        self.bra = self.cursor
        v_3 = self.limit - self.cursor
        if not self.in_grouping_b(FinnishStemmer.g_v):
            self.limit_backward = v_2
            return False
        self.cursor = self.limit - v_3
        self.slice_del()
        self.limit_backward = v_2
        if self.cursor < self.I_p2:
            return False
        v_5 = self.limit_backward
        self.limit_backward = self.I_p2
        self.ket = self.cursor
        among_var = self.find_among_b(FinnishStemmer.a_10)
        if among_var == 0:
            self.limit_backward = v_5
            return False
        self.bra = self.cursor
        self.limit_backward = v_5
        if among_var == 1:
            try:
                if not self.eq_s_b("po"):
                    raise lab0()
                return False
            except lab0: pass
        self.slice_del()
        return True

    def __r_tidy(self):
        if self.cursor < self.I_p1:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_p1
        v_3 = self.limit - self.cursor
        try:
            v_4 = self.limit - self.cursor
            if not self.__r_LV():
                raise lab0()
            self.cursor = self.limit - v_4
            self.ket = self.cursor
            if self.cursor <= self.limit_backward:
                raise lab0()
            self.cursor -= 1
            self.bra = self.cursor
            self.slice_del()
        except lab0: pass
        self.cursor = self.limit - v_3
        v_5 = self.limit - self.cursor
        try:
            self.ket = self.cursor
            if not self.in_grouping_b(FinnishStemmer.g_AEI):
                raise lab0()
            self.bra = self.cursor
            if not self.in_grouping_b(FinnishStemmer.g_C):
                raise lab0()
            self.slice_del()
        except lab0: pass
        self.cursor = self.limit - v_5
        v_6 = self.limit - self.cursor
        try:
            self.ket = self.cursor
            if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "j":
                raise lab0()
            self.cursor -= 1
            self.bra = self.cursor
            while True:
                try:
                    if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "o":
                        raise lab1()
                    self.cursor -= 1
                    break
                except lab1: pass
                if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "u":
                    raise lab0()
                self.cursor -= 1
                break
            self.slice_del()
        except lab0: pass
        self.cursor = self.limit - v_6
        v_7 = self.limit - self.cursor
        try:
            self.ket = self.cursor
            if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "o":
                raise lab0()
            self.cursor -= 1
            self.bra = self.cursor
            if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "j":
                raise lab0()
            self.cursor -= 1
            self.slice_del()
        except lab0: pass
        self.cursor = self.limit - v_7
        self.limit_backward = v_2
        v_8 = self.limit - self.cursor
        try:
            if not self.go_in_grouping_b(FinnishStemmer.g_v):
                raise lab0()
            self.ket = self.cursor
            if not self.in_grouping_b(FinnishStemmer.g_C):
                raise lab0()
            self.bra = self.cursor
            S_x = self.slice_to()
            if not self.eq_s_b(S_x):
                raise lab0()
            self.slice_del()
        except lab0: pass
        self.cursor = self.limit - v_8
        self.ket = self.cursor
        if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "'":
            return False
        self.cursor -= 1
        self.bra = self.cursor
        self.slice_del()
        return True

    def _stem(self):
        v_1 = self.cursor
        self.__r_mark_regions()
        self.cursor = v_1
        self.B_ending_removed = False
        self.limit_backward = self.cursor
        self.cursor = self.limit
        v_2 = self.limit - self.cursor
        self.__r_particle_etc()
        self.cursor = self.limit - v_2
        v_3 = self.limit - self.cursor
        self.__r_possessive()
        self.cursor = self.limit - v_3
        v_4 = self.limit - self.cursor
        self.__r_case_ending()
        self.cursor = self.limit - v_4
        v_5 = self.limit - self.cursor
        self.__r_other_endings()
        self.cursor = self.limit - v_5
        while True:
            try:
                if not self.B_ending_removed:
                    raise lab0()
                v_6 = self.limit - self.cursor
                self.__r_i_plural()
                self.cursor = self.limit - v_6
                break
            except lab0: pass
            v_7 = self.limit - self.cursor
            self.__r_t_plural()
            self.cursor = self.limit - v_7
            break
        v_8 = self.limit - self.cursor
        self.__r_tidy()
        self.cursor = self.limit - v_8
        self.cursor = self.limit_backward
        return True

    a_0 = [
        Among("pa", -1, 1),
        Among("sti", -1, 2),
        Among("kaan", -1, 1),
        Among("han", -1, 1),
        Among("kin", -1, 1),
        Among("hän", -1, 1),
        Among("kään", -1, 1),
        Among("ko", -1, 1),
        Among("pä", -1, 1),
        Among("kö", -1, 1)
    ]

    a_1 = [
        Among("lla", -1, -1),
        Among("na", -1, -1),
        Among("ssa", -1, -1),
        Among("ta", -1, -1),
        Among("lta", 3, -1),
        Among("sta", 3, -1)
    ]

    a_2 = [
        Among("llä", -1, -1),
        Among("nä", -1, -1),
        Among("ssä", -1, -1),
        Among("tä", -1, -1),
        Among("ltä", 3, -1),
        Among("stä", 3, -1)
    ]

    a_3 = [
        Among("lle", -1, -1),
        Among("ine", -1, -1)
    ]

    a_4 = [
        Among("nsa", -1, 3),
        Among("mme", -1, 3),
        Among("nne", -1, 3),
        Among("ni", -1, 2),
        Among("si", -1, 1),
        Among("an", -1, 4),
        Among("en", -1, 6),
        Among("än", -1, 5),
        Among("nsä", -1, 3)
    ]

    a_5 = [
        Among("aa", -1, -1),
        Among("ee", -1, -1),
        Among("ii", -1, -1),
        Among("oo", -1, -1),
        Among("uu", -1, -1),
        Among("ää", -1, -1),
        Among("öö", -1, -1)
    ]

    a_6 = [
        Among("'", -1, -1),
        Among("ai", -1, -1),
        Among("ei", -1, -1),
        Among("ii", -1, -1),
        Among("oi", -1, -1),
        Among("ui", -1, -1),
        Among("äi", -1, -1),
        Among("öi", -1, -1)
    ]

    a_7 = [
        Among("a", -1, 2),
        Among("lla", 0, -1),
        Among("na", 0, -1),
        Among("ssa", 0, -1),
        Among("ta", 0, -1),
        Among("lta", 4, -1),
        Among("sta", 4, -1),
        Among("tta", 4, 3),
        Among("lle", -1, -1),
        Among("ine", -1, -1),
        Among("ksi", -1, -1),
        Among("n", -1, 1),
        Among("han", 11, -1, __r_A),
        Among("den", 11, -1, __r_VI),
        Among("seen", 11, -1, __r_LV),
        Among("hen", 11, -1, __r_E),
        Among("tten", 11, -1, __r_VI),
        Among("hin", 11, -1, __r_I),
        Among("siin", 11, -1, __r_VI),
        Among("hon", 11, -1, __r_O),
        Among("hun", 11, -1, __r_U),
        Among("hän", 11, -1, __r_A_),
        Among("hön", 11, -1, __r_O_),
        Among("ä", -1, 2),
        Among("llä", 23, -1),
        Among("nä", 23, -1),
        Among("ssä", 23, -1),
        Among("tä", 23, -1),
        Among("ltä", 27, -1),
        Among("stä", 27, -1),
        Among("ttä", 27, 3)
    ]

    a_8 = [
        Among("eja", -1, -1),
        Among("mma", -1, 1),
        Among("imma", 1, -1),
        Among("mpa", -1, 1),
        Among("impa", 3, -1),
        Among("mmi", -1, 1),
        Among("immi", 5, -1),
        Among("mpi", -1, 1),
        Among("impi", 7, -1),
        Among("ejä", -1, -1),
        Among("mmä", -1, 1),
        Among("immä", 10, -1),
        Among("mpä", -1, 1),
        Among("impä", 12, -1)
    ]

    a_9 = [
        Among("i", -1, -1),
        Among("j", -1, -1)
    ]

    a_10 = [
        Among("mma", -1, 1),
        Among("imma", 0, -1)
    ]


class lab0(BaseException): pass


class lab1(BaseException): pass



# Generated from czech.sbl by Snowball 3.1.1 - https://snowballstem.org/

from .basestemmer import BaseStemmer
from .among import Among


class CzechStemmer(BaseStemmer):
    '''
    This class implements the stemming algorithm defined by a snowball script.
    Generated from czech.sbl by Snowball 3.1.1 - https://snowballstem.org/
    '''

    g_v = {"a", "e", "i", "o", "u", "y", "á", "é", "í", "ó", "ú", "ý", "ě", "ů"}

    g_v_or_syllabic_c = {"a", "e", "i", "l", "o", "r", "u", "y", "á", "é", "í", "ó", "ú", "ý", "ě", "ů"}

    g_ev_ending = {"h", "k", "n", "r", "t", "z"}

    g_env_ending = {"b", "c", "d", "h", "k", "p", "r", "s", "t", "v", "z", "č", "š", "ž"}

    I_p1 = 0

    def __r_mark_regions(self):
        v_1 = self.cursor
        if self.cursor + 3 > self.limit:
            return False
        self.cursor += 3
        I_x = self.cursor
        self.cursor = v_1
        self.I_p1 = self.limit
        v_2 = self.cursor
        try:
            while True:
                try:
                    if not self.in_grouping(CzechStemmer.g_v):
                        raise lab1()
                    break
                except lab1: pass
                if self.cursor >= self.limit:
                    raise lab0()
                self.cursor += 1
                if not self.go_out_grouping(CzechStemmer.g_v_or_syllabic_c):
                    raise lab0()
                self.cursor += 1
                break
            if not self.go_in_grouping(CzechStemmer.g_v):
                raise lab0()
            self.cursor += 1
            self.I_p1 = self.cursor
            try:
                if self.I_p1 >= I_x:
                    raise lab1()
                self.I_p1 = I_x
            except lab1: pass
        except lab0: pass
        self.cursor = v_2
        return True

    def __r_palatalise_e(self):
        self.ket = self.cursor
        among_var = self.find_among_b(CzechStemmer.a_0)
        if among_var == 0:
            return False
        self.bra = self.cursor
        if among_var > 0:
            self.slice_from(CzechStemmer.as_0[among_var - 1])
        return True

    def __r_palatalise_i(self):
        self.ket = self.cursor
        among_var = self.find_among_b(CzechStemmer.a_1)
        if among_var == 0:
            return False
        self.bra = self.cursor
        if among_var > 0:
            self.slice_from(CzechStemmer.as_1[among_var - 1])
        return True

    def __r_possessive_suffix(self):
        self.ket = self.cursor
        among_var = self.find_among_b(CzechStemmer.a_2)
        if among_var == 0:
            return False
        self.bra = self.cursor
        if self.I_p1 > self.cursor:
            return False
        if among_var == 1:
            self.slice_del()
        else:
            self.slice_del()
            v_1 = self.limit - self.cursor
            try:
                if not self.__r_palatalise_i():
                    self.cursor = self.limit - v_1
                    raise lab0()
            except lab0: pass
        return True

    def __r_case_suffix(self):
        if self.cursor < self.I_p1:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_p1
        self.ket = self.cursor
        among_var = self.find_among_b(CzechStemmer.a_6)
        if among_var == 0:
            self.limit_backward = v_2
            return False
        self.bra = self.cursor
        self.limit_backward = v_2
        if among_var == 1:
            self.slice_del()
        elif among_var == 2:
            self.slice_del()
            v_3 = self.limit - self.cursor
            try:
                if not self.__r_palatalise_e():
                    self.cursor = self.limit - v_3
                    raise lab0()
            except lab0: pass
        elif among_var == 3:
            among_var = self.find_among_b(CzechStemmer.a_3)
            self.slice_from(CzechStemmer.as_3[among_var - 1])
        elif among_var == 4:
            v_4 = self.limit - self.cursor
            if not self.out_grouping_b(CzechStemmer.g_v):
                return False
            self.cursor = self.limit - v_4
            try:
                if not self.eq_s_b("tř"):
                    raise lab0()
                return False
            except lab0: pass
            self.slice_from("b")
        elif among_var == 5:
            v_5 = self.limit - self.cursor
            if not self.out_grouping_b(CzechStemmer.g_v):
                return False
            self.cursor = self.limit - v_5
            self.slice_del()
            self.insert(self.cursor, self.cursor, "c")
            v_6 = self.limit - self.cursor
            try:
                if not self.__r_palatalise_e():
                    self.cursor = self.limit - v_6
                    raise lab0()
            except lab0: pass
        elif among_var == 6:
            v_7 = self.limit - self.cursor
            if not self.out_grouping_b(CzechStemmer.g_v):
                return False
            self.cursor = self.limit - v_7
            v_8 = self.limit - self.cursor
            try:
                if self.find_among_b(CzechStemmer.a_4) == 0:
                    raise lab0()
                return False
            except lab0: pass
            self.cursor = self.limit - v_8
            self.slice_from("k")
        elif among_var == 7:
            if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "n":
                return False
            self.cursor -= 1
            self.bra = self.cursor
            self.slice_from("ňk")
        elif among_var == 8:
            v_9 = self.limit - self.cursor
            if not self.in_grouping_b(CzechStemmer.g_env_ending):
                return False
            self.cursor = self.limit - v_9
            self.slice_from("n")
        elif among_var == 9:
            if self.find_among_b(CzechStemmer.a_5) == 0:
                return False
            self.slice_from("t")
        elif among_var == 10:
            if not self.in_grouping_b(CzechStemmer.g_ev_ending):
                return False
            self.slice_from("v")
        elif among_var == 11:
            self.slice_from("t")
        else:
            self.slice_del()
            v_10 = self.limit - self.cursor
            try:
                if not self.__r_palatalise_i():
                    self.cursor = self.limit - v_10
                    raise lab0()
            except lab0: pass
        return True

    def _stem(self):
        if not self.__r_mark_regions():
            return False
        self.limit_backward = self.cursor
        self.cursor = self.limit
        v_1 = self.limit - self.cursor
        self.__r_case_suffix()
        self.cursor = self.limit - v_1
        v_2 = self.limit - self.cursor
        self.__r_possessive_suffix()
        self.cursor = self.limit - v_2
        self.cursor = self.limit_backward
        return True

    a_0 = [
        Among("c", -1, 1),
        Among("nc", 0, -1),
        Among("ínc", 1, 2),
        Among("avc", 0, -1),
        Among("ovc", 0, -1)
    ]
    as_0 = ("k", "ínk")

    a_1 = [
        Among("c", -1, 1),
        Among("nc", 0, -1),
        Among("ínc", 1, 2),
        Among("avc", 0, -1),
        Among("ovc", 0, -1),
        Among("čt", -1, 3),
        Among("št", -1, 4),
        Among("dešt", 6, -1),
        Among("lešt", 6, -1),
        Among("išt", 6, -1),
        Among("poušt", 6, -1),
        Among("ášt", 6, -1),
        Among("íšt", 6, -1)
    ]
    as_1 = ("k", "ínk", "ck", "sk")

    a_2 = [
        Among("in", -1, 2),
        Among("ov", -1, 1),
        Among("ův", -1, 1)
    ]

    a_3 = [
        Among("", -1, 2),
        Among("l", 0, 1),
        Among("tl", 1, 2),
        Among("s", 0, 1),
        Among("es", 3, 2),
        Among("č", 0, 1),
        Among("eč", 5, 2),
        Among("ř", 0, 1),
        Among("ž", 0, 1)
    ]
    as_3 = ("", "et")

    a_4 = [
        Among("obl", -1, -1),
        Among("sn", -1, -1),
        Among("dot", -1, -1)
    ]

    a_5 = [
        Among("uc", -1, -1),
        Among("h", -1, -1),
        Among("ok", -1, -1),
        Among("kar", -1, -1),
        Among("č", -1, -1)
    ]

    a_6 = [
        Among("a", -1, 1),
        Among("ama", 0, 1),
        Among("ata", 0, 1),
        Among("eb", -1, 4),
        Among("ec", -1, 5),
        Among("e", -1, 2),
        Among("ete", 5, 3),
        Among("ěte", 5, 1),
        Among("ech", -1, 2),
        Among("atech", 8, 1),
        Among("ách", -1, 1),
        Among("ích", -1, 12),
        Among("ých", -1, 1),
        Among("i", -1, 12),
        Among("mi", 13, 1),
        Among("ami", 14, 1),
        Among("emi", 14, 2),
        Among("ími", 14, 12),
        Among("ými", 14, 1),
        Among("ěmi", 14, 1),
        Among("ťmi", 14, 11),
        Among("eti", 13, 3),
        Among("ěti", 13, 1),
        Among("ovi", 13, 1),
        Among("ek", -1, 6),
        Among("ěk", -1, 7),
        Among("em", -1, 2),
        Among("etem", 26, 3),
        Among("ětem", 26, 1),
        Among("ám", -1, 1),
        Among("ém", -1, 1),
        Among("ím", -1, 12),
        Among("ým", -1, 1),
        Among("ěm", -1, 1),
        Among("ům", -1, 1),
        Among("atům", 34, 1),
        Among("o", -1, 1),
        Among("ého", 36, 1),
        Among("ího", 36, 12),
        Among("us", -1, 1),
        Among("at", -1, 1),
        Among("et", -1, 9),
        Among("u", -1, 1),
        Among("ému", 42, 1),
        Among("ímu", 42, 12),
        Among("ou", 42, 1),
        Among("ev", -1, 10),
        Among("y", -1, 1),
        Among("aty", 47, 1),
        Among("á", -1, 1),
        Among("é", -1, 1),
        Among("ové", 50, 1),
        Among("í", -1, 12),
        Among("ý", -1, 1),
        Among("ě", -1, 1),
        Among("eň", -1, 8),
        Among("ť", -1, 11),
        Among("ů", -1, 1)
    ]


class lab0(BaseException): pass


class lab1(BaseException): pass



# Generated from greek.sbl by Snowball 3.1.1 - https://snowballstem.org/

from .basestemmer import BaseStemmer
from .among import Among


class GreekStemmer(BaseStemmer):
    '''
    This class implements the stemming algorithm defined by a snowball script.
    Generated from greek.sbl by Snowball 3.1.1 - https://snowballstem.org/
    '''

    g_v = {"α", "ε", "η", "ι", "ο", "υ", "ω"}

    g_v2 = {"α", "ε", "η", "ι", "ο", "ω"}

    B_test1 = False

    def __r_tolower(self):
        while True:
            v_1 = self.limit - self.cursor
            try:
                self.ket = self.cursor
                among_var = self.find_among_b(GreekStemmer.a_0)
                self.bra = self.cursor
                if among_var == 1:
                    self.slice_from("α")
                elif among_var == 2:
                    self.slice_from("β")
                elif among_var == 3:
                    self.slice_from("γ")
                elif among_var == 4:
                    self.slice_from("δ")
                elif among_var == 5:
                    self.slice_from("ε")
                elif among_var == 6:
                    self.slice_from("ζ")
                elif among_var == 7:
                    self.slice_from("η")
                elif among_var == 8:
                    self.slice_from("θ")
                elif among_var == 9:
                    self.slice_from("ι")
                elif among_var == 10:
                    self.slice_from("κ")
                elif among_var == 11:
                    self.slice_from("λ")
                elif among_var == 12:
                    self.slice_from("μ")
                elif among_var == 13:
                    self.slice_from("ν")
                elif among_var == 14:
                    self.slice_from("ξ")
                elif among_var == 15:
                    self.slice_from("ο")
                elif among_var == 16:
                    self.slice_from("π")
                elif among_var == 17:
                    self.slice_from("ρ")
                elif among_var == 18:
                    self.slice_from("σ")
                elif among_var == 19:
                    self.slice_from("τ")
                elif among_var == 20:
                    self.slice_from("υ")
                elif among_var == 21:
                    self.slice_from("φ")
                elif among_var == 22:
                    self.slice_from("χ")
                elif among_var == 23:
                    self.slice_from("ψ")
                elif among_var == 24:
                    self.slice_from("ω")
                else:
                    if self.cursor <= self.limit_backward:
                        raise lab0()
                    self.cursor -= 1
                continue
            except lab0: pass
            self.cursor = self.limit - v_1
            break
        return True

    def __r_step_1(self):
        self.ket = self.cursor
        among_var = self.find_among_b(GreekStemmer.a_1)
        if among_var == 0:
            return False
        self.bra = self.cursor
        self.slice_from(GreekStemmer.as_1[among_var - 1])
        self.B_test1 = False
        return True

    def __r_step_s1(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_3) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        among_var = self.find_among_b(GreekStemmer.a_2)
        if among_var == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        self.slice_from(GreekStemmer.as_2[among_var - 1])
        return True

    def __r_step_s2(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_5) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_4) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        self.slice_from("ων")
        return True

    def __r_step_s3(self):
        while True:
            v_1 = self.limit - self.cursor
            try:
                self.ket = self.cursor
                if not self.eq_s_b("ισα"):
                    raise lab0()
                self.bra = self.cursor
                if self.cursor > self.limit_backward:
                    raise lab0()
                self.slice_from("ισ")
                break
            except lab0: pass
            self.cursor = self.limit - v_1
            self.ket = self.cursor
            break
        if self.find_among_b(GreekStemmer.a_7) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        among_var = self.find_among_b(GreekStemmer.a_6)
        if among_var == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        self.slice_from(GreekStemmer.as_6[among_var - 1])
        return True

    def __r_step_s4(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_9) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_8) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        self.slice_from("ι")
        return True

    def __r_step_s5(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_11) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        among_var = self.find_among_b(GreekStemmer.a_10)
        if among_var == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        self.slice_from(GreekStemmer.as_10[among_var - 1])
        return True

    def __r_step_s6(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_14) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        while True:
            v_1 = self.limit - self.cursor
            try:
                self.ket = self.cursor
                self.bra = self.cursor
                among_var = self.find_among_b(GreekStemmer.a_12)
                if among_var == 0:
                    raise lab0()
                if self.cursor > self.limit_backward:
                    raise lab0()
                self.slice_from(GreekStemmer.as_12[among_var - 1])
                break
            except lab0: pass
            self.cursor = self.limit - v_1
            self.ket = self.cursor
            among_var = self.find_among_b(GreekStemmer.a_13)
            if among_var == 0:
                return False
            self.bra = self.cursor
            self.slice_from(GreekStemmer.as_13[among_var - 1])
            break
        return True

    def __r_step_s7(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_16) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_15) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        self.slice_from("αρακ")
        return True

    def __r_step_s8(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_18) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        while True:
            v_1 = self.limit - self.cursor
            try:
                self.ket = self.cursor
                self.bra = self.cursor
                among_var = self.find_among_b(GreekStemmer.a_17)
                if among_var == 0:
                    raise lab0()
                if self.cursor > self.limit_backward:
                    raise lab0()
                self.slice_from(GreekStemmer.as_17[among_var - 1])
                break
            except lab0: pass
            self.cursor = self.limit - v_1
            self.ket = self.cursor
            self.bra = self.cursor
            if not self.eq_s_b("κορ"):
                return False
            self.slice_from("ιτσ")
            break
        return True

    def __r_step_s9(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_21) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        while True:
            v_1 = self.limit - self.cursor
            try:
                self.ket = self.cursor
                self.bra = self.cursor
                if self.find_among_b(GreekStemmer.a_19) == 0:
                    raise lab0()
                if self.cursor > self.limit_backward:
                    raise lab0()
                self.slice_from("ιδ")
                break
            except lab0: pass
            self.cursor = self.limit - v_1
            self.ket = self.cursor
            self.bra = self.cursor
            if self.find_among_b(GreekStemmer.a_20) == 0:
                return False
            self.slice_from("ιδ")
            break
        return True

    def __r_step_s10(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_23) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_22) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        self.slice_from("ισκ")
        return True

    def __r_step_2a(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_24) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        v_1 = self.limit - self.cursor
        try:
            if self.find_among_b(GreekStemmer.a_25) == 0:
                raise lab0()
            return False
        except lab0: pass
        self.cursor = self.limit - v_1
        c = self.cursor
        self.insert(self.cursor, self.cursor, "αδ")
        self.cursor = c
        return True

    def __r_step_2b(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_26) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_27) == 0:
            return False
        self.slice_from("εδ")
        return True

    def __r_step_2c(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_28) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_29) == 0:
            return False
        self.slice_from("ουδ")
        return True

    def __r_step_2d(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_30) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_31) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        self.slice_from("ε")
        return True

    def __r_step_3(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_32) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if not self.in_grouping_b(GreekStemmer.g_v):
            return False
        self.slice_from("ι")
        return True

    def __r_step_4(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_33) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        while True:
            v_1 = self.limit - self.cursor
            try:
                self.ket = self.cursor
                self.bra = self.cursor
                if not self.in_grouping_b(GreekStemmer.g_v):
                    raise lab0()
                self.slice_from("ικ")
                break
            except lab0: pass
            self.cursor = self.limit - v_1
            self.ket = self.cursor
            break
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_34) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        self.slice_from("ικ")
        return True

    def __r_step_5a(self):
        v_1 = self.limit - self.cursor
        try:
            self.ket = self.cursor
            if not self.eq_s_b("αγαμε"):
                raise lab0()
            self.bra = self.cursor
            if self.cursor > self.limit_backward:
                raise lab0()
            self.slice_from("αγαμ")
        except lab0: pass
        self.cursor = self.limit - v_1
        v_2 = self.limit - self.cursor
        try:
            self.ket = self.cursor
            if self.find_among_b(GreekStemmer.a_35) == 0:
                raise lab0()
            self.bra = self.cursor
            self.slice_del()
            self.B_test1 = False
        except lab0: pass
        self.cursor = self.limit - v_2
        self.ket = self.cursor
        if not self.eq_s_b("αμε"):
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_36) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        self.slice_from("αμ")
        return True

    def __r_step_5b(self):
        v_1 = self.limit - self.cursor
        try:
            self.ket = self.cursor
            if self.find_among_b(GreekStemmer.a_38) == 0:
                raise lab0()
            self.bra = self.cursor
            self.slice_del()
            self.B_test1 = False
            self.ket = self.cursor
            self.bra = self.cursor
            if self.find_among_b(GreekStemmer.a_37) == 0:
                raise lab0()
            if self.cursor > self.limit_backward:
                raise lab0()
            self.slice_from("αγαν")
        except lab0: pass
        self.cursor = self.limit - v_1
        self.ket = self.cursor
        if not self.eq_s_b("ανε"):
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        while True:
            v_2 = self.limit - self.cursor
            try:
                self.ket = self.cursor
                self.bra = self.cursor
                if not self.in_grouping_b(GreekStemmer.g_v2):
                    raise lab0()
                self.slice_from("αν")
                break
            except lab0: pass
            self.cursor = self.limit - v_2
            self.ket = self.cursor
            break
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_39) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        self.slice_from("αν")
        return True

    def __r_step_5c(self):
        v_1 = self.limit - self.cursor
        try:
            self.ket = self.cursor
            if not self.eq_s_b("ησετε"):
                raise lab0()
            self.bra = self.cursor
            self.slice_del()
            self.B_test1 = False
        except lab0: pass
        self.cursor = self.limit - v_1
        self.ket = self.cursor
        if not self.eq_s_b("ετε"):
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        while True:
            v_2 = self.limit - self.cursor
            try:
                self.ket = self.cursor
                self.bra = self.cursor
                if not self.in_grouping_b(GreekStemmer.g_v2):
                    raise lab0()
                self.slice_from("ετ")
                break
            except lab0: pass
            self.cursor = self.limit - v_2
            try:
                self.ket = self.cursor
                self.bra = self.cursor
                if self.find_among_b(GreekStemmer.a_40) == 0:
                    raise lab0()
                self.slice_from("ετ")
                break
            except lab0: pass
            self.cursor = self.limit - v_2
            self.ket = self.cursor
            break
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_41) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        self.slice_from("ετ")
        return True

    def __r_step_5d(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_42) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        while True:
            v_1 = self.limit - self.cursor
            try:
                self.ket = self.cursor
                self.bra = self.cursor
                if not self.eq_s_b("αρχ"):
                    raise lab0()
                if self.cursor > self.limit_backward:
                    raise lab0()
                self.slice_from("οντ")
                break
            except lab0: pass
            self.cursor = self.limit - v_1
            self.ket = self.cursor
            self.bra = self.cursor
            if not self.eq_s_b("κρε"):
                return False
            self.slice_from("ωντ")
            break
        return True

    def __r_step_5e(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_43) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if not self.eq_s_b("ον"):
            return False
        if self.cursor > self.limit_backward:
            return False
        self.slice_from("ομαστ")
        return True

    def __r_step_5f(self):
        v_1 = self.limit - self.cursor
        try:
            self.ket = self.cursor
            if not self.eq_s_b("ιεστε"):
                raise lab0()
            self.bra = self.cursor
            self.slice_del()
            self.B_test1 = False
            self.ket = self.cursor
            self.bra = self.cursor
            if self.find_among_b(GreekStemmer.a_44) == 0:
                raise lab0()
            if self.cursor > self.limit_backward:
                raise lab0()
            self.slice_from("ιεστ")
        except lab0: pass
        self.cursor = self.limit - v_1
        self.ket = self.cursor
        if not self.eq_s_b("εστε"):
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_45) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        self.slice_from("ιεστ")
        return True

    def __r_step_5g(self):
        v_1 = self.limit - self.cursor
        try:
            self.ket = self.cursor
            if self.find_among_b(GreekStemmer.a_46) == 0:
                raise lab0()
            self.bra = self.cursor
            self.slice_del()
            self.B_test1 = False
        except lab0: pass
        self.cursor = self.limit - v_1
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_49) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        while True:
            v_2 = self.limit - self.cursor
            try:
                self.ket = self.cursor
                self.bra = self.cursor
                if self.find_among_b(GreekStemmer.a_47) == 0:
                    raise lab0()
                self.slice_from("ηκ")
                break
            except lab0: pass
            self.cursor = self.limit - v_2
            self.ket = self.cursor
            self.bra = self.cursor
            if self.find_among_b(GreekStemmer.a_48) == 0:
                return False
            if self.cursor > self.limit_backward:
                return False
            self.slice_from("ηκ")
            break
        return True

    def __r_step_5h(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_52) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        while True:
            v_1 = self.limit - self.cursor
            try:
                self.ket = self.cursor
                self.bra = self.cursor
                if self.find_among_b(GreekStemmer.a_50) == 0:
                    raise lab0()
                self.slice_from("ουσ")
                break
            except lab0: pass
            self.cursor = self.limit - v_1
            self.ket = self.cursor
            self.bra = self.cursor
            if self.find_among_b(GreekStemmer.a_51) == 0:
                return False
            if self.cursor > self.limit_backward:
                return False
            self.slice_from("ουσ")
            break
        return True

    def __r_step_5i(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_55) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        while True:
            v_1 = self.limit - self.cursor
            try:
                self.ket = self.cursor
                self.bra = self.cursor
                if not self.eq_s_b("κολλ"):
                    raise lab0()
                self.slice_from("αγ")
                break
            except lab0: pass
            self.cursor = self.limit - v_1
            while True:
                v_2 = self.limit - self.cursor
                try:
                    self.ket = self.cursor
                    self.bra = self.cursor
                    among_var = self.find_among_b(GreekStemmer.a_53)
                    if among_var == 0:
                        raise lab0()
                    if among_var == 1:
                        self.slice_from("αγ")
                    break
                except lab0: pass
                self.cursor = self.limit - v_2
                self.ket = self.cursor
                self.bra = self.cursor
                if self.find_among_b(GreekStemmer.a_54) == 0:
                    return False
                if self.cursor > self.limit_backward:
                    return False
                self.slice_from("αγ")
                break
            break
        return True

    def __r_step_5j(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_56) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_57) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        self.slice_from("ησ")
        return True

    def __r_step_5k(self):
        self.ket = self.cursor
        if not self.eq_s_b("ηστε"):
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_58) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        self.slice_from("ηστ")
        return True

    def __r_step_5l(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_59) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_60) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        self.slice_from("ουν")
        return True

    def __r_step_5m(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_61) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        self.B_test1 = False
        self.ket = self.cursor
        self.bra = self.cursor
        if self.find_among_b(GreekStemmer.a_62) == 0:
            return False
        if self.cursor > self.limit_backward:
            return False
        self.slice_from("ουμ")
        return True

    def __r_step_6(self):
        v_1 = self.limit - self.cursor
        try:
            self.ket = self.cursor
            if self.find_among_b(GreekStemmer.a_63) == 0:
                raise lab0()
            self.bra = self.cursor
            self.slice_from("μα")
        except lab0: pass
        self.cursor = self.limit - v_1
        if not self.B_test1:
            return False
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_64) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        return True

    def __r_step_7(self):
        self.ket = self.cursor
        if self.find_among_b(GreekStemmer.a_65) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        return True

    def _stem(self):
        self.limit_backward = self.cursor
        self.cursor = self.limit
        v_1 = self.limit - self.cursor
        self.__r_tolower()
        self.cursor = self.limit - v_1
        if len(self.current) < 3:
            return False
        self.B_test1 = True
        v_2 = self.limit - self.cursor
        self.__r_step_1()
        self.cursor = self.limit - v_2
        v_3 = self.limit - self.cursor
        self.__r_step_s1()
        self.cursor = self.limit - v_3
        v_4 = self.limit - self.cursor
        self.__r_step_s2()
        self.cursor = self.limit - v_4
        v_5 = self.limit - self.cursor
        self.__r_step_s3()
        self.cursor = self.limit - v_5
        v_6 = self.limit - self.cursor
        self.__r_step_s4()
        self.cursor = self.limit - v_6
        v_7 = self.limit - self.cursor
        self.__r_step_s5()
        self.cursor = self.limit - v_7
        v_8 = self.limit - self.cursor
        self.__r_step_s6()
        self.cursor = self.limit - v_8
        v_9 = self.limit - self.cursor
        self.__r_step_s7()
        self.cursor = self.limit - v_9
        v_10 = self.limit - self.cursor
        self.__r_step_s8()
        self.cursor = self.limit - v_10
        v_11 = self.limit - self.cursor
        self.__r_step_s9()
        self.cursor = self.limit - v_11
        v_12 = self.limit - self.cursor
        self.__r_step_s10()
        self.cursor = self.limit - v_12
        v_13 = self.limit - self.cursor
        self.__r_step_2a()
        self.cursor = self.limit - v_13
        v_14 = self.limit - self.cursor
        self.__r_step_2b()
        self.cursor = self.limit - v_14
        v_15 = self.limit - self.cursor
        self.__r_step_2c()
        self.cursor = self.limit - v_15
        v_16 = self.limit - self.cursor
        self.__r_step_2d()
        self.cursor = self.limit - v_16
        v_17 = self.limit - self.cursor
        self.__r_step_3()
        self.cursor = self.limit - v_17
        v_18 = self.limit - self.cursor
        self.__r_step_4()
        self.cursor = self.limit - v_18
        v_19 = self.limit - self.cursor
        self.__r_step_5a()
        self.cursor = self.limit - v_19
        v_20 = self.limit - self.cursor
        self.__r_step_5b()
        self.cursor = self.limit - v_20
        v_21 = self.limit - self.cursor
        self.__r_step_5c()
        self.cursor = self.limit - v_21
        v_22 = self.limit - self.cursor
        self.__r_step_5d()
        self.cursor = self.limit - v_22
        v_23 = self.limit - self.cursor
        self.__r_step_5e()
        self.cursor = self.limit - v_23
        v_24 = self.limit - self.cursor
        self.__r_step_5f()
        self.cursor = self.limit - v_24
        v_25 = self.limit - self.cursor
        self.__r_step_5g()
        self.cursor = self.limit - v_25
        v_26 = self.limit - self.cursor
        self.__r_step_5h()
        self.cursor = self.limit - v_26
        v_27 = self.limit - self.cursor
        self.__r_step_5j()
        self.cursor = self.limit - v_27
        v_28 = self.limit - self.cursor
        self.__r_step_5i()
        self.cursor = self.limit - v_28
        v_29 = self.limit - self.cursor
        self.__r_step_5k()
        self.cursor = self.limit - v_29
        v_30 = self.limit - self.cursor
        self.__r_step_5l()
        self.cursor = self.limit - v_30
        v_31 = self.limit - self.cursor
        self.__r_step_5m()
        self.cursor = self.limit - v_31
        v_32 = self.limit - self.cursor
        self.__r_step_6()
        self.cursor = self.limit - v_32
        v_33 = self.limit - self.cursor
        self.__r_step_7()
        self.cursor = self.limit - v_33
        self.cursor = self.limit_backward
        return True

    a_0 = [
        Among("", -1, 25),
        Among("Ά", 0, 1),
        Among("Έ", 0, 5),
        Among("Ή", 0, 7),
        Among("Ί", 0, 9),
        Among("Ό", 0, 15),
        Among("Ύ", 0, 20),
        Among("Ώ", 0, 24),
        Among("ΐ", 0, 7),
        Among("Α", 0, 1),
        Among("Β", 0, 2),
        Among("Γ", 0, 3),
        Among("Δ", 0, 4),
        Among("Ε", 0, 5),
        Among("Ζ", 0, 6),
        Among("Η", 0, 7),
        Among("Θ", 0, 8),
        Among("Ι", 0, 9),
        Among("Κ", 0, 10),
        Among("Λ", 0, 11),
        Among("Μ", 0, 12),
        Among("Ν", 0, 13),
        Among("Ξ", 0, 14),
        Among("Ο", 0, 15),
        Among("Π", 0, 16),
        Among("Ρ", 0, 17),
        Among("Σ", 0, 18),
        Among("Τ", 0, 19),
        Among("Υ", 0, 20),
        Among("Φ", 0, 21),
        Among("Χ", 0, 22),
        Among("Ψ", 0, 23),
        Among("Ω", 0, 24),
        Among("Ϊ", 0, 9),
        Among("Ϋ", 0, 20),
        Among("ά", 0, 1),
        Among("έ", 0, 5),
        Among("ή", 0, 7),
        Among("ί", 0, 9),
        Among("ΰ", 0, 20),
        Among("ς", 0, 18),
        Among("ϊ", 0, 7),
        Among("ϋ", 0, 20),
        Among("ό", 0, 15),
        Among("ύ", 0, 20),
        Among("ώ", 0, 24)
    ]

    a_1 = [
        Among("σκαγια", -1, 2),
        Among("φαγια", -1, 1),
        Among("ολογια", -1, 3),
        Among("σογια", -1, 4),
        Among("τατογια", -1, 5),
        Among("κρεατα", -1, 6),
        Among("περατα", -1, 7),
        Among("τερατα", -1, 8),
        Among("γεγονοτα", -1, 11),
        Among("καθεστωτα", -1, 10),
        Among("φωτα", -1, 9),
        Among("περατη", -1, 7),
        Among("σκαγιων", -1, 2),
        Among("φαγιων", -1, 1),
        Among("ολογιων", -1, 3),
        Among("σογιων", -1, 4),
        Among("τατογιων", -1, 5),
        Among("κρεατων", -1, 6),
        Among("περατων", -1, 7),
        Among("τερατων", -1, 8),
        Among("γεγονοτων", -1, 11),
        Among("καθεστωτων", -1, 10),
        Among("φωτων", -1, 9),
        Among("κρεασ", -1, 6),
        Among("περασ", -1, 7),
        Among("τερασ", -1, 8),
        Among("γεγονοσ", -1, 11),
        Among("κρεατοσ", -1, 6),
        Among("περατοσ", -1, 7),
        Among("τερατοσ", -1, 8),
        Among("γεγονοτοσ", -1, 11),
        Among("καθεστωτοσ", -1, 10),
        Among("φωτοσ", -1, 9),
        Among("καθεστωσ", -1, 10),
        Among("φωσ", -1, 9),
        Among("σκαγιου", -1, 2),
        Among("φαγιου", -1, 1),
        Among("ολογιου", -1, 3),
        Among("σογιου", -1, 4),
        Among("τατογιου", -1, 5)
    ]
    as_1 = ("φα", "σκα", "ολο", "σο", "τατο", "κρε", "περ", "τερ", "φω", "καθεστ", "γεγον")

    a_2 = [
        Among("πα", -1, 1),
        Among("ξαναπα", 0, 1),
        Among("επα", 0, 1),
        Among("περιπα", 0, 1),
        Among("αναμπα", 0, 1),
        Among("εμπα", 0, 1),
        Among("β", -1, 2),
        Among("δανε", -1, 1),
        Among("βαθυρι", -1, 2),
        Among("βαρκ", -1, 2),
        Among("μαρκ", -1, 2),
        Among("λ", -1, 2),
        Among("μ", -1, 2),
        Among("κορν", -1, 2),
        Among("αθρο", -1, 1),
        Among("συναθρο", 14, 1),
        Among("π", -1, 2),
        Among("ιμπ", 16, 2),
        Among("ρ", -1, 2),
        Among("μαρ", 18, 2),
        Among("αμπαρ", 18, 2),
        Among("γκρ", 18, 2),
        Among("βολβορ", 18, 2),
        Among("γλυκορ", 18, 2),
        Among("πιπερορ", 18, 2),
        Among("πρ", 18, 2),
        Among("μπρ", 25, 2),
        Among("αρρ", 18, 2),
        Among("γλυκυρ", 18, 2),
        Among("πολυρ", 18, 2),
        Among("λου", -1, 2)
    ]
    as_2 = ("ι", "ιζ")

    a_3 = [
        Among("ιζα", -1, 1),
        Among("ιζε", -1, 1),
        Among("ιζαμε", -1, 1),
        Among("ιζουμε", -1, 1),
        Among("ιζανε", -1, 1),
        Among("ιζουνε", -1, 1),
        Among("ιζατε", -1, 1),
        Among("ιζετε", -1, 1),
        Among("ιζει", -1, 1),
        Among("ιζαν", -1, 1),
        Among("ιζουν", -1, 1),
        Among("ιζεσ", -1, 1),
        Among("ιζεισ", -1, 1),
        Among("ιζω", -1, 1)
    ]

    a_4 = [
        Among("βι", -1, 1),
        Among("λι", -1, 1),
        Among("αλ", -1, 1),
        Among("εν", -1, 1),
        Among("σ", -1, 1),
        Among("χ", -1, 1),
        Among("υψ", -1, 1),
        Among("ζω", -1, 1)
    ]

    a_5 = [
        Among("ωθηκα", -1, 1),
        Among("ωθηκε", -1, 1),
        Among("ωθηκαμε", -1, 1),
        Among("ωθηκανε", -1, 1),
        Among("ωθηκατε", -1, 1),
        Among("ωθηκαν", -1, 1),
        Among("ωθηκεσ", -1, 1)
    ]

    a_6 = [
        Among("ξαναπα", -1, 1),
        Among("επα", -1, 1),
        Among("περιπα", -1, 1),
        Among("αναμπα", -1, 1),
        Among("εμπα", -1, 1),
        Among("χαρτοπα", -1, 1),
        Among("εξαρχα", -1, 1),
        Among("γε", -1, 2),
        Among("γκε", -1, 2),
        Among("κλε", -1, 1),
        Among("εκλε", 9, 1),
        Among("απεκλε", 10, 1),
        Among("αποκλε", 9, 1),
        Among("εσωκλε", 9, 1),
        Among("δανε", -1, 1),
        Among("πε", -1, 1),
        Among("επε", 15, 1),
        Among("μετεπε", 16, 1),
        Among("εσε", -1, 1),
        Among("γκ", -1, 2),
        Among("μ", -1, 2),
        Among("πουκαμ", 20, 2),
        Among("κομ", 20, 2),
        Among("αν", -1, 2),
        Among("ολο", -1, 2),
        Among("αθρο", -1, 1),
        Among("συναθρο", 25, 1),
        Among("π", -1, 2),
        Among("λαρ", -1, 2),
        Among("δημοκρατ", -1, 2),
        Among("αφ", -1, 2),
        Among("γιγαντοαφ", 30, 2)
    ]
    as_6 = ("ι", "ισ")

    a_7 = [
        Among("ισα", -1, 1),
        Among("ισαμε", -1, 1),
        Among("ισανε", -1, 1),
        Among("ισε", -1, 1),
        Among("ισατε", -1, 1),
        Among("ισαν", -1, 1),
        Among("ισεσ", -1, 1)
    ]

    a_8 = [
        Among("ξαναπα", -1, 1),
        Among("επα", -1, 1),
        Among("περιπα", -1, 1),
        Among("αναμπα", -1, 1),
        Among("εμπα", -1, 1),
        Among("χαρτοπα", -1, 1),
        Among("εξαρχα", -1, 1),
        Among("κλε", -1, 1),
        Among("εκλε", 7, 1),
        Among("απεκλε", 8, 1),
        Among("αποκλε", 7, 1),
        Among("εσωκλε", 7, 1),
        Among("δανε", -1, 1),
        Among("πε", -1, 1),
        Among("επε", 13, 1),
        Among("μετεπε", 14, 1),
        Among("εσε", -1, 1),
        Among("αθρο", -1, 1),
        Among("συναθρο", 17, 1)
    ]

    a_9 = [
        Among("ισουμε", -1, 1),
        Among("ισουνε", -1, 1),
        Among("ισετε", -1, 1),
        Among("ισει", -1, 1),
        Among("ισουν", -1, 1),
        Among("ισεισ", -1, 1),
        Among("ισω", -1, 1)
    ]

    a_10 = [
        Among("ατα", -1, 2),
        Among("φα", -1, 2),
        Among("ηφα", 1, 2),
        Among("μεγ", -1, 2),
        Among("λυγ", -1, 2),
        Among("ηδ", -1, 2),
        Among("κλε", -1, 1),
        Among("εσωκλε", 6, 1),
        Among("πλε", -1, 1),
        Among("δανε", -1, 1),
        Among("σε", -1, 1),
        Among("ασε", 10, 1),
        Among("καθ", -1, 2),
        Among("εχθ", -1, 2),
        Among("κακ", -1, 2),
        Among("μακ", -1, 2),
        Among("σκ", -1, 2),
        Among("φιλ", -1, 2),
        Among("κυλ", -1, 2),
        Among("μ", -1, 2),
        Among("γεμ", 19, 2),
        Among("αχν", -1, 2),
        Among("συναθρο", -1, 1),
        Among("π", -1, 2),
        Among("απ", 23, 2),
        Among("εμπ", 23, 2),
        Among("ευπ", 23, 2),
        Among("αρ", -1, 2),
        Among("αορ", -1, 2),
        Among("γυρ", -1, 2),
        Among("χρ", -1, 2),
        Among("χωρ", -1, 2),
        Among("κτ", -1, 2),
        Among("ακτ", 32, 2),
        Among("χτ", -1, 2),
        Among("αχτ", 34, 2),
        Among("ταχ", -1, 2),
        Among("σχ", -1, 2),
        Among("ασχ", 37, 2),
        Among("υψ", -1, 2)
    ]
    as_10 = ("ι", "ιστ")

    a_11 = [
        Among("ιστα", -1, 1),
        Among("ιστε", -1, 1),
        Among("ιστη", -1, 1),
        Among("ιστοι", -1, 1),
        Among("ιστων", -1, 1),
        Among("ιστο", -1, 1),
        Among("ιστεσ", -1, 1),
        Among("ιστησ", -1, 1),
        Among("ιστοσ", -1, 1),
        Among("ιστουσ", -1, 1),
        Among("ιστου", -1, 1)
    ]

    a_12 = [
        Among("εγκλε", -1, 1),
        Among("αποκλε", -1, 1),
        Among("δανε", -1, 2),
        Among("αντιδανε", 2, 2),
        Among("σε", -1, 1),
        Among("μετασε", 4, 1),
        Among("μικροσε", 4, 1)
    ]
    as_12 = ("ισμ", "ι")

    a_13 = [
        Among("ατομικ", -1, 2),
        Among("εθνικ", -1, 4),
        Among("τοπικ", -1, 7),
        Among("εκλεκτικ", -1, 5),
        Among("σκεπτικ", -1, 6),
        Among("γνωστικ", -1, 3),
        Among("αγνωστικ", 5, 1),
        Among("αλεξανδριν", -1, 8),
        Among("θεατριν", -1, 10),
        Among("βυζαντιν", -1, 9)
    ]
    as_13 = ("αγνωστ", "ατομ", "γνωστ", "εθν", "εκλεκτ", "σκεπτ", "τοπ", "αλεξανδρ", "βυζαντ", "θεατρ")

    a_14 = [
        Among("ισμοι", -1, 1),
        Among("ισμων", -1, 1),
        Among("ισμο", -1, 1),
        Among("ισμοσ", -1, 1),
        Among("ισμουσ", -1, 1),
        Among("ισμου", -1, 1)
    ]

    a_15 = [
        Among("σ", -1, 1),
        Among("χ", -1, 1)
    ]

    a_16 = [
        Among("ουδακια", -1, 1),
        Among("αρακια", -1, 1),
        Among("ουδακι", -1, 1),
        Among("αρακι", -1, 1)
    ]

    a_17 = [
        Among("β", -1, 2),
        Among("βαμβ", 0, 1),
        Among("σλοβ", 0, 1),
        Among("τσεχοσλοβ", 2, 1),
        Among("καρδ", -1, 2),
        Among("ζ", -1, 2),
        Among("τζ", 5, 1),
        Among("κ", -1, 1),
        Among("καπακ", 7, 1),
        Among("σοκ", 7, 1),
        Among("σκ", 7, 1),
        Among("βαλ", -1, 2),
        Among("μαλ", -1, 1),
        Among("γλ", -1, 2),
        Among("τριπολ", -1, 2),
        Among("πλ", -1, 1),
        Among("λουλ", -1, 1),
        Among("φυλ", -1, 1),
        Among("καιμ", -1, 1),
        Among("κλιμ", -1, 1),
        Among("φαρμ", -1, 1),
        Among("γιαν", -1, 2),
        Among("σπαν", -1, 1),
        Among("ηγουμεν", -1, 2),
        Among("κον", -1, 1),
        Among("μακρυν", -1, 2),
        Among("π", -1, 2),
        Among("κατραπ", 26, 1),
        Among("ρ", -1, 1),
        Among("βρ", 28, 1),
        Among("λαβρ", 29, 1),
        Among("αμβρ", 29, 1),
        Among("μερ", 28, 1),
        Among("πατερ", 28, 2),
        Among("ανθρ", 28, 1),
        Among("κορ", 28, 1),
        Among("σ", -1, 1),
        Among("ναγκασ", 36, 1),
        Among("τοσ", 36, 2),
        Among("μουστ", -1, 1),
        Among("ρυ", -1, 1),
        Among("φ", -1, 1),
        Among("σφ", 41, 1),
        Among("αλισφ", 42, 1),
        Among("νυφ", 41, 2),
        Among("χ", -1, 1)
    ]
    as_17 = ("ακ", "ιτσ")

    a_18 = [
        Among("ακια", -1, 1),
        Among("αρακια", 0, 1),
        Among("ιτσα", -1, 1),
        Among("ακι", -1, 1),
        Among("αρακι", 3, 1),
        Among("ιτσων", -1, 1),
        Among("ιτσασ", -1, 1),
        Among("ιτσεσ", -1, 1)
    ]

    a_19 = [
        Among("ψαλ", -1, 1),
        Among("αιφν", -1, 1),
        Among("ολο", -1, 1),
        Among("ιρ", -1, 1)
    ]

    a_20 = [
        Among("ε", -1, 1),
        Among("παιχν", -1, 1)
    ]

    a_21 = [
        Among("ιδια", -1, 1),
        Among("ιδιων", -1, 1),
        Among("ιδιο", -1, 1)
    ]

    a_22 = [
        Among("ιβ", -1, 1),
        Among("δ", -1, 1),
        Among("φραγκ", -1, 1),
        Among("λυκ", -1, 1),
        Among("οβελ", -1, 1),
        Among("μην", -1, 1),
        Among("ρ", -1, 1)
    ]

    a_23 = [
        Among("ισκε", -1, 1),
        Among("ισκο", -1, 1),
        Among("ισκοσ", -1, 1),
        Among("ισκου", -1, 1)
    ]

    a_24 = [
        Among("αδων", -1, 1),
        Among("αδεσ", -1, 1)
    ]

    a_25 = [
        Among("γιαγι", -1, -1),
        Among("θει", -1, -1),
        Among("οκ", -1, -1),
        Among("μαμ", -1, -1),
        Among("μαν", -1, -1),
        Among("μπαμπ", -1, -1),
        Among("πεθερ", -1, -1),
        Among("πατερ", -1, -1),
        Among("κυρ", -1, -1),
        Among("νταντ", -1, -1)
    ]

    a_26 = [
        Among("εδων", -1, 1),
        Among("εδεσ", -1, 1)
    ]

    a_27 = [
        Among("μιλ", -1, 1),
        Among("δαπ", -1, 1),
        Among("γηπ", -1, 1),
        Among("ιπ", -1, 1),
        Among("εμπ", -1, 1),
        Among("οπ", -1, 1),
        Among("κρασπ", -1, 1),
        Among("υπ", -1, 1)
    ]

    a_28 = [
        Among("ουδων", -1, 1),
        Among("ουδεσ", -1, 1)
    ]

    a_29 = [
        Among("τραγ", -1, 1),
        Among("φε", -1, 1),
        Among("καλιακ", -1, 1),
        Among("αρκ", -1, 1),
        Among("σκ", -1, 1),
        Among("πεταλ", -1, 1),
        Among("βελ", -1, 1),
        Among("λουλ", -1, 1),
        Among("φλ", -1, 1),
        Among("χν", -1, 1),
        Among("πλεξ", -1, 1),
        Among("σπ", -1, 1),
        Among("φρ", -1, 1),
        Among("σ", -1, 1),
        Among("λιχ", -1, 1)
    ]

    a_30 = [
        Among("εων", -1, 1),
        Among("εωσ", -1, 1)
    ]

    a_31 = [
        Among("δ", -1, 1),
        Among("ιδ", 0, 1),
        Among("θ", -1, 1),
        Among("γαλ", -1, 1),
        Among("ελ", -1, 1),
        Among("ν", -1, 1),
        Among("π", -1, 1),
        Among("παρ", -1, 1)
    ]

    a_32 = [
        Among("ια", -1, 1),
        Among("ιων", -1, 1),
        Among("ιου", -1, 1)
    ]

    a_33 = [
        Among("ικα", -1, 1),
        Among("ικων", -1, 1),
        Among("ικο", -1, 1),
        Among("ικου", -1, 1)
    ]

    a_34 = [
        Among("αδ", -1, 1),
        Among("συναδ", 0, 1),
        Among("καταδ", 0, 1),
        Among("αντιδ", -1, 1),
        Among("ενδ", -1, 1),
        Among("φυλοδ", -1, 1),
        Among("υποδ", -1, 1),
        Among("πρωτοδ", -1, 1),
        Among("εξωδ", -1, 1),
        Among("ηθ", -1, 1),
        Among("ανηθ", 9, 1),
        Among("ξικ", -1, 1),
        Among("αλ", -1, 1),
        Among("αμμοχαλ", 12, 1),
        Among("συνομηλ", -1, 1),
        Among("μπολ", -1, 1),
        Among("μουλ", -1, 1),
        Among("τσαμ", -1, 1),
        Among("βρωμ", -1, 1),
        Among("αμαν", -1, 1),
        Among("μπαν", -1, 1),
        Among("καλλιν", -1, 1),
        Among("ποστελν", -1, 1),
        Among("φιλον", -1, 1),
        Among("καλπ", -1, 1),
        Among("γερ", -1, 1),
        Among("χασ", -1, 1),
        Among("μποσ", -1, 1),
        Among("πλιατσ", -1, 1),
        Among("πετσ", -1, 1),
        Among("πιτσ", -1, 1),
        Among("φυσ", -1, 1),
        Among("μπαγιατ", -1, 1),
        Among("νιτ", -1, 1),
        Among("πικαντ", -1, 1),
        Among("σερτ", -1, 1)
    ]

    a_35 = [
        Among("αγαμε", -1, 1),
        Among("ηκαμε", -1, 1),
        Among("ηθηκαμε", 1, 1),
        Among("ησαμε", -1, 1),
        Among("ουσαμε", -1, 1)
    ]

    a_36 = [
        Among("βουβ", -1, 1),
        Among("ξεθ", -1, 1),
        Among("πεθ", -1, 1),
        Among("αποθ", -1, 1),
        Among("αποκ", -1, 1),
        Among("ουλ", -1, 1),
        Among("αναπ", -1, 1),
        Among("πικρ", -1, 1),
        Among("ποτ", -1, 1),
        Among("αποστ", -1, 1),
        Among("χ", -1, 1),
        Among("σιχ", 10, 1)
    ]

    a_37 = [
        Among("τρ", -1, 1),
        Among("τσ", -1, 1)
    ]

    a_38 = [
        Among("αγανε", -1, 1),
        Among("ηκανε", -1, 1),
        Among("ηθηκανε", 1, 1),
        Among("ησανε", -1, 1),
        Among("ουσανε", -1, 1),
        Among("οντανε", -1, 1),
        Among("ιοντανε", 5, 1),
        Among("ουντανε", -1, 1),
        Among("ιουντανε", 7, 1),
        Among("οτανε", -1, 1),
        Among("ιοτανε", 9, 1)
    ]

    a_39 = [
        Among("ταβ", -1, 1),
        Among("νταβ", 0, 1),
        Among("ψηλοταβ", 0, 1),
        Among("λιβ", -1, 1),
        Among("κλιβ", 3, 1),
        Among("ξηροκλιβ", 4, 1),
        Among("γ", -1, 1),
        Among("αγ", 6, 1),
        Among("τραγ", 7, 1),
        Among("τσαγ", 7, 1),
        Among("αθιγγ", 6, 1),
        Among("τσιγγ", 6, 1),
        Among("ατσιγγ", 11, 1),
        Among("στεγ", 6, 1),
        Among("απηγ", 6, 1),
        Among("σιγ", 6, 1),
        Among("ανοργ", 6, 1),
        Among("ενοργ", 6, 1),
        Among("καλπουζ", -1, 1),
        Among("θ", -1, 1),
        Among("μωαμεθ", 19, 1),
        Among("πιθ", 19, 1),
        Among("απιθ", 21, 1),
        Among("δεκ", -1, 1),
        Among("πελεκ", -1, 1),
        Among("ικ", -1, 1),
        Among("ανικ", 25, 1),
        Among("βουλκ", -1, 1),
        Among("βασκ", -1, 1),
        Among("βραχυκ", -1, 1),
        Among("γαλ", -1, 1),
        Among("καταγαλ", 30, 1),
        Among("ολογαλ", 30, 1),
        Among("βαθυγαλ", 30, 1),
        Among("μελ", -1, 1),
        Among("καστελ", -1, 1),
        Among("πορτολ", -1, 1),
        Among("πλ", -1, 1),
        Among("διπλ", 37, 1),
        Among("λαοπλ", 37, 1),
        Among("ψυχοπλ", 37, 1),
        Among("ουλ", -1, 1),
        Among("μ", -1, 1),
        Among("ολιγοδαμ", 42, 1),
        Among("μουσουλμ", 42, 1),
        Among("δραδουμ", 42, 1),
        Among("βραχμ", 42, 1),
        Among("ν", -1, 1),
        Among("αμερικαν", 47, 1),
        Among("π", -1, 1),
        Among("αδαπ", 49, 1),
        Among("χαμηλοδαπ", 49, 1),
        Among("πολυδαπ", 49, 1),
        Among("κοπ", 49, 1),
        Among("υποκοπ", 53, 1),
        Among("τσοπ", 49, 1),
        Among("σπ", 49, 1),
        Among("ερ", -1, 1),
        Among("γερ", 57, 1),
        Among("βετερ", 57, 1),
        Among("λουθηρ", -1, 1),
        Among("κορμορ", -1, 1),
        Among("περιτρ", -1, 1),
        Among("ουρ", -1, 1),
        Among("σ", -1, 1),
        Among("βασ", 64, 1),
        Among("πολισ", 64, 1),
        Among("σαρακατσ", 64, 1),
        Among("θυσ", 64, 1),
        Among("διατ", -1, 1),
        Among("πλατ", -1, 1),
        Among("τσαρλατ", -1, 1),
        Among("τετ", -1, 1),
        Among("πουριτ", -1, 1),
        Among("σουλτ", -1, 1),
        Among("μαιντ", -1, 1),
        Among("ζωντ", -1, 1),
        Among("καστ", -1, 1),
        Among("φ", -1, 1),
        Among("διαφ", 78, 1),
        Among("στεφ", 78, 1),
        Among("φωτοστεφ", 80, 1),
        Among("περηφ", 78, 1),
        Among("υπερηφ", 82, 1),
        Among("κοιλαρφ", 78, 1),
        Among("πενταρφ", 78, 1),
        Among("ορφ", 78, 1),
        Among("χ", -1, 1),
        Among("αμηχ", 87, 1),
        Among("βιομηχ", 87, 1),
        Among("μεγλοβιομηχ", 89, 1),
        Among("καπνοβιομηχ", 89, 1),
        Among("μικροβιομηχ", 89, 1),
        Among("πολυμηχ", 87, 1),
        Among("λιχ", 87, 1)
    ]

    a_40 = [
        Among("ενδ", -1, 1),
        Among("συνδ", -1, 1),
        Among("οδ", -1, 1),
        Among("διαθ", -1, 1),
        Among("καθ", -1, 1),
        Among("ραθ", -1, 1),
        Among("ταθ", -1, 1),
        Among("τιθ", -1, 1),
        Among("εκθ", -1, 1),
        Among("ενθ", -1, 1),
        Among("συνθ", -1, 1),
        Among("ροθ", -1, 1),
        Among("υπερθ", -1, 1),
        Among("σθ", -1, 1),
        Among("ευθ", -1, 1),
        Among("αρκ", -1, 1),
        Among("ωφελ", -1, 1),
        Among("βολ", -1, 1),
        Among("αιν", -1, 1),
        Among("πον", -1, 1),
        Among("ρον", -1, 1),
        Among("συν", -1, 1),
        Among("βαρ", -1, 1),
        Among("βρ", -1, 1),
        Among("αιρ", -1, 1),
        Among("φορ", -1, 1),
        Among("ευρ", -1, 1),
        Among("πυρ", -1, 1),
        Among("χωρ", -1, 1),
        Among("νετ", -1, 1),
        Among("σχ", -1, 1)
    ]

    a_41 = [
        Among("παγ", -1, 1),
        Among("δ", -1, 1),
        Among("αδ", 1, 1),
        Among("θ", -1, 1),
        Among("αθ", 3, 1),
        Among("τοκ", -1, 1),
        Among("σκ", -1, 1),
        Among("παρακαλ", -1, 1),
        Among("σκελ", -1, 1),
        Among("απλ", -1, 1),
        Among("εμ", -1, 1),
        Among("αν", -1, 1),
        Among("βεν", -1, 1),
        Among("βαρον", -1, 1),
        Among("κοπ", -1, 1),
        Among("σερπ", -1, 1),
        Among("αβαρ", -1, 1),
        Among("εναρ", -1, 1),
        Among("αβρ", -1, 1),
        Among("μπορ", -1, 1),
        Among("θαρρ", -1, 1),
        Among("ντρ", -1, 1),
        Among("υ", -1, 1),
        Among("νιφ", -1, 1),
        Among("συρφ", -1, 1)
    ]

    a_42 = [
        Among("οντασ", -1, 1),
        Among("ωντασ", -1, 1)
    ]

    a_43 = [
        Among("ομαστε", -1, 1),
        Among("ιομαστε", 0, 1)
    ]

    a_44 = [
        Among("π", -1, 1),
        Among("απ", 0, 1),
        Among("ακαταπ", 1, 1),
        Among("συμπ", 0, 1),
        Among("ασυμπ", 3, 1),
        Among("αμεταμφ", -1, 1)
    ]

    a_45 = [
        Among("ζ", -1, 1),
        Among("αλ", -1, 1),
        Among("παρακαλ", 1, 1),
        Among("εκτελ", -1, 1),
        Among("μ", -1, 1),
        Among("ξ", -1, 1),
        Among("προ", -1, 1),
        Among("αρ", -1, 1),
        Among("νισ", -1, 1)
    ]

    a_46 = [
        Among("ηθηκα", -1, 1),
        Among("ηθηκε", -1, 1),
        Among("ηθηκεσ", -1, 1)
    ]

    a_47 = [
        Among("πιθ", -1, 1),
        Among("οθ", -1, 1),
        Among("ναρθ", -1, 1),
        Among("σκουλ", -1, 1),
        Among("σκωλ", -1, 1),
        Among("σφ", -1, 1)
    ]

    a_48 = [
        Among("θ", -1, 1),
        Among("διαθ", 0, 1),
        Among("παρακαταθ", 0, 1),
        Among("συνθ", 0, 1),
        Among("προσθ", 0, 1)
    ]

    a_49 = [
        Among("ηκα", -1, 1),
        Among("ηκε", -1, 1),
        Among("ηκεσ", -1, 1)
    ]

    a_50 = [
        Among("φαγ", -1, 1),
        Among("ληγ", -1, 1),
        Among("φρυδ", -1, 1),
        Among("μαντιλ", -1, 1),
        Among("μαλλ", -1, 1),
        Among("ομ", -1, 1),
        Among("βλεπ", -1, 1),
        Among("ποδαρ", -1, 1),
        Among("κυματ", -1, 1),
        Among("πρωτ", -1, 1),
        Among("λαχ", -1, 1),
        Among("πανταχ", -1, 1)
    ]

    a_51 = [
        Among("τσα", -1, 1),
        Among("χαδ", -1, 1),
        Among("μεδ", -1, 1),
        Among("λαμπιδ", -1, 1),
        Among("δε", -1, 1),
        Among("πλε", -1, 1),
        Among("μεσαζ", -1, 1),
        Among("δεσποζ", -1, 1),
        Among("αιθ", -1, 1),
        Among("φαρμακ", -1, 1),
        Among("αγκ", -1, 1),
        Among("ανηκ", -1, 1),
        Among("λ", -1, 1),
        Among("μ", -1, 1),
        Among("αμ", 13, 1),
        Among("βρομ", 13, 1),
        Among("υποτειν", -1, 1),
        Among("εκλιπ", -1, 1),
        Among("ρ", -1, 1),
        Among("ενδιαφερ", 18, 1),
        Among("αναρρ", 18, 1),
        Among("πατ", -1, 1),
        Among("καθαρευ", -1, 1),
        Among("δευτερευ", -1, 1),
        Among("λεχ", -1, 1)
    ]

    a_52 = [
        Among("ουσα", -1, 1),
        Among("ουσε", -1, 1),
        Among("ουσεσ", -1, 1)
    ]

    a_53 = [
        Among("πελ", -1, 1),
        Among("λλ", -1, 1),
        Among("σμην", -1, 1),
        Among("ρπ", -1, 1),
        Among("πρ", -1, 1),
        Among("φρ", -1, 1),
        Among("χορτ", -1, 1),
        Among("οφ", -1, 1),
        Among("ψοφ", 7, -1),
        Among("σφ", -1, 1),
        Among("λοχ", -1, 1),
        Among("ναυλοχ", 10, -1)
    ]

    a_54 = [
        Among("αμαλλι", -1, 1),
        Among("λ", -1, 1),
        Among("αμαλ", 1, 1),
        Among("μ", -1, 1),
        Among("ουλαμ", 3, 1),
        Among("εν", -1, 1),
        Among("δερβεν", 5, 1),
        Among("π", -1, 1),
        Among("αειπ", 7, 1),
        Among("αρτιπ", 7, 1),
        Among("συμπ", 7, 1),
        Among("νεοπ", 7, 1),
        Among("κροκαλοπ", 7, 1),
        Among("ολοπ", 7, 1),
        Among("προσωποπ", 7, 1),
        Among("σιδηροπ", 7, 1),
        Among("δροσοπ", 7, 1),
        Among("ασπ", 7, 1),
        Among("ανυπ", 7, 1),
        Among("ρ", -1, 1),
        Among("ασπαρ", 19, 1),
        Among("χαρ", 19, 1),
        Among("αχαρ", 21, 1),
        Among("απερ", 19, 1),
        Among("τρ", 19, 1),
        Among("ουρ", 19, 1),
        Among("τ", -1, 1),
        Among("διατ", 26, 1),
        Among("επιτ", 26, 1),
        Among("συντ", 26, 1),
        Among("ομοτ", 26, 1),
        Among("νομοτ", 30, 1),
        Among("αποτ", 26, 1),
        Among("υποτ", 26, 1),
        Among("αβαστ", 26, 1),
        Among("αιμοστ", 26, 1),
        Among("προστ", 26, 1),
        Among("ανυστ", 26, 1),
        Among("ναυ", -1, 1),
        Among("αφ", -1, 1),
        Among("ξεφ", -1, 1),
        Among("αδηφ", -1, 1),
        Among("παμφ", -1, 1),
        Among("πολυφ", -1, 1)
    ]

    a_55 = [
        Among("αγα", -1, 1),
        Among("αγε", -1, 1),
        Among("αγεσ", -1, 1)
    ]

    a_56 = [
        Among("ησα", -1, 1),
        Among("ησε", -1, 1),
        Among("ησου", -1, 1)
    ]

    a_57 = [
        Among("ν", -1, 1),
        Among("δωδεκαν", 0, 1),
        Among("επταν", 0, 1),
        Among("μεγαλον", 0, 1),
        Among("ερημον", 0, 1),
        Among("χερσον", 0, 1)
    ]

    a_58 = [
        Among("σβ", -1, 1),
        Among("ασβ", 0, 1),
        Among("απλ", -1, 1),
        Among("αειμν", -1, 1),
        Among("χρ", -1, 1),
        Among("αχρ", 4, 1),
        Among("κοινοχρ", 4, 1),
        Among("δυσχρ", 4, 1),
        Among("ευχρ", 4, 1),
        Among("παλιμψ", -1, 1)
    ]

    a_59 = [
        Among("ουνε", -1, 1),
        Among("ηθουνε", 0, 1),
        Among("ησουνε", 0, 1)
    ]

    a_60 = [
        Among("σπι", -1, 1),
        Among("ν", -1, 1),
        Among("εξων", 1, 1),
        Among("ρ", -1, 1),
        Among("στραβομουτσ", -1, 1),
        Among("κακομουτσ", -1, 1)
    ]

    a_61 = [
        Among("ουμε", -1, 1),
        Among("ηθουμε", 0, 1),
        Among("ησουμε", 0, 1)
    ]

    a_62 = [
        Among("αζ", -1, 1),
        Among("ωριοπλ", -1, 1),
        Among("ασουσ", -1, 1),
        Among("παρασουσ", 2, 1),
        Among("αλλοσουσ", -1, 1),
        Among("φ", -1, 1),
        Among("χ", -1, 1)
    ]

    a_63 = [
        Among("ματα", -1, 1),
        Among("ματων", -1, 1),
        Among("ματοσ", -1, 1)
    ]

    a_64 = [
        Among("α", -1, 1),
        Among("ιουμα", 0, 1),
        Among("ομουνα", 0, 1),
        Among("ιομουνα", 2, 1),
        Among("οσουνα", 0, 1),
        Among("ιοσουνα", 4, 1),
        Among("ε", -1, 1),
        Among("αγατε", 6, 1),
        Among("ηκατε", 6, 1),
        Among("ηθηκατε", 8, 1),
        Among("ησατε", 6, 1),
        Among("ουσατε", 6, 1),
        Among("ειτε", 6, 1),
        Among("ηθειτε", 12, 1),
        Among("ιεμαστε", 6, 1),
        Among("ουμαστε", 6, 1),
        Among("ιουμαστε", 15, 1),
        Among("ιεσαστε", 6, 1),
        Among("οσαστε", 6, 1),
        Among("ιοσαστε", 18, 1),
        Among("η", -1, 1),
        Among("ι", -1, 1),
        Among("αμαι", 21, 1),
        Among("ιεμαι", 21, 1),
        Among("ομαι", 21, 1),
        Among("ουμαι", 21, 1),
        Among("ασαι", 21, 1),
        Among("εσαι", 21, 1),
        Among("ιεσαι", 27, 1),
        Among("αται", 21, 1),
        Among("εται", 21, 1),
        Among("ιεται", 30, 1),
        Among("ονται", 21, 1),
        Among("ουνται", 21, 1),
        Among("ιουνται", 33, 1),
        Among("ει", 21, 1),
        Among("αει", 35, 1),
        Among("ηθει", 35, 1),
        Among("ησει", 35, 1),
        Among("οι", 21, 1),
        Among("αν", -1, 1),
        Among("αγαν", 40, 1),
        Among("ηκαν", 40, 1),
        Among("ηθηκαν", 42, 1),
        Among("ησαν", 40, 1),
        Among("ουσαν", 40, 1),
        Among("οντουσαν", 45, 1),
        Among("ιοντουσαν", 46, 1),
        Among("ονταν", 40, 1),
        Among("ιονταν", 48, 1),
        Among("ουνταν", 40, 1),
        Among("ιουνταν", 50, 1),
        Among("οταν", 40, 1),
        Among("ιοταν", 52, 1),
        Among("ομασταν", 40, 1),
        Among("ιομασταν", 54, 1),
        Among("οσασταν", 40, 1),
        Among("ιοσασταν", 56, 1),
        Among("ουν", -1, 1),
        Among("ηθουν", 58, 1),
        Among("ομουν", 58, 1),
        Among("ιομουν", 60, 1),
        Among("ησουν", 58, 1),
        Among("οσουν", 58, 1),
        Among("ιοσουν", 63, 1),
        Among("ων", -1, 1),
        Among("ηδων", 65, 1),
        Among("ο", -1, 1),
        Among("ασ", -1, 1),
        Among("εσ", -1, 1),
        Among("ηδεσ", 69, 1),
        Among("ησεσ", 69, 1),
        Among("ησ", -1, 1),
        Among("εισ", -1, 1),
        Among("ηθεισ", 73, 1),
        Among("οσ", -1, 1),
        Among("υσ", -1, 1),
        Among("ουσ", 76, 1),
        Among("υ", -1, 1),
        Among("ου", 78, 1),
        Among("ω", -1, 1),
        Among("αω", 80, 1),
        Among("ηθω", 80, 1),
        Among("ησω", 80, 1)
    ]

    a_65 = [
        Among("οτερ", -1, 1),
        Among("εστερ", -1, 1),
        Among("υτερ", -1, 1),
        Among("ωτερ", -1, 1),
        Among("οτατ", -1, 1),
        Among("εστατ", -1, 1),
        Among("υτατ", -1, 1),
        Among("ωτατ", -1, 1)
    ]


class lab0(BaseException): pass



# Generated from dutch_porter.sbl by Snowball 3.1.1 - https://snowballstem.org/

from .basestemmer import BaseStemmer
from .among import Among


class DutchPorterStemmer(BaseStemmer):
    '''
    This class implements the stemming algorithm defined by a snowball script.
    Generated from dutch_porter.sbl by Snowball 3.1.1 - https://snowballstem.org/
    '''

    g_v = {"a", "e", "i", "o", "u", "y", "è"}

    g_v_I = {"I", "a", "e", "i", "o", "u", "y", "è"}

    g_v_j = {"a", "e", "i", "j", "o", "u", "y", "è"}

    I_p2 = 0
    I_p1 = 0
    B_e_found = False

    def __r_prelude(self):
        v_1 = self.cursor
        while True:
            v_2 = self.cursor
            try:
                self.bra = self.cursor
                among_var = self.find_among(DutchPorterStemmer.a_0)
                self.ket = self.cursor
                if among_var == 1:
                    self.slice_from("a")
                elif among_var == 2:
                    self.slice_from("e")
                elif among_var == 3:
                    self.slice_from("i")
                elif among_var == 4:
                    self.slice_from("o")
                elif among_var == 5:
                    self.slice_from("u")
                else:
                    if self.cursor >= self.limit:
                        raise lab0()
                    self.cursor += 1
                continue
            except lab0: pass
            self.cursor = v_2
            break
        self.cursor = v_1
        v_3 = self.cursor
        try:
            self.bra = self.cursor
            if self.cursor == self.limit or self.current[self.cursor] != "y":
                self.cursor = v_3
                raise lab0()
            self.cursor += 1
            self.ket = self.cursor
            self.slice_from("Y")
        except lab0: pass
        while True:
            v_4 = self.cursor
            try:
                if not self.go_out_grouping(DutchPorterStemmer.g_v):
                    raise lab0()
                self.cursor += 1
                v_5 = self.cursor
                try:
                    self.bra = self.cursor
                    while True:
                        v_6 = self.cursor
                        try:
                            if self.cursor == self.limit or self.current[self.cursor] != "i":
                                raise lab2()
                            self.cursor += 1
                            self.ket = self.cursor
                            v_7 = self.cursor
                            try:
                                if not self.in_grouping(DutchPorterStemmer.g_v):
                                    raise lab3()
                                self.slice_from("I")
                            except lab3: pass
                            self.cursor = v_7
                            break
                        except lab2: pass
                        self.cursor = v_6
                        if self.cursor == self.limit or self.current[self.cursor] != "y":
                            self.cursor = v_5
                            raise lab1()
                        self.cursor += 1
                        self.ket = self.cursor
                        self.slice_from("Y")
                        break
                except lab1: pass
                continue
            except lab0: pass
            self.cursor = v_4
            break
        return True

    def __r_mark_regions(self):
        self.I_p1 = self.limit
        self.I_p2 = self.limit
        v_1 = self.cursor
        if self.cursor + 3 > self.limit:
            return False
        self.cursor += 3
        I_x = self.cursor
        self.cursor = v_1
        if not self.go_out_grouping(DutchPorterStemmer.g_v):
            return False
        self.cursor += 1
        if not self.go_in_grouping(DutchPorterStemmer.g_v):
            return False
        self.cursor += 1
        self.I_p1 = self.cursor
        try:
            if self.I_p1 >= I_x:
                raise lab0()
            self.I_p1 = I_x
        except lab0: pass
        if not self.go_out_grouping(DutchPorterStemmer.g_v):
            return False
        self.cursor += 1
        if not self.go_in_grouping(DutchPorterStemmer.g_v):
            return False
        self.cursor += 1
        self.I_p2 = self.cursor
        return True

    def __r_postlude(self):
        while True:
            v_1 = self.cursor
            try:
                self.bra = self.cursor
                among_var = self.find_among(DutchPorterStemmer.a_1)
                self.ket = self.cursor
                if among_var == 1:
                    self.slice_from("y")
                elif among_var == 2:
                    self.slice_from("i")
                else:
                    if self.cursor >= self.limit:
                        raise lab0()
                    self.cursor += 1
                continue
            except lab0: pass
            self.cursor = v_1
            break
        return True

    def __r_R1(self):
        return self.I_p1 <= self.cursor

    def __r_R2(self):
        return self.I_p2 <= self.cursor

    def __r_undouble(self):
        v_1 = self.limit - self.cursor
        if self.find_among_b(DutchPorterStemmer.a_2) == 0:
            return False
        self.cursor = self.limit - v_1
        self.ket = self.cursor
        if self.cursor <= self.limit_backward:
            return False
        self.cursor -= 1
        self.bra = self.cursor
        self.slice_del()
        return True

    def __r_e_ending(self):
        self.B_e_found = False
        self.ket = self.cursor
        if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "e":
            return False
        self.cursor -= 1
        self.bra = self.cursor
        if not self.__r_R1():
            return False
        v_1 = self.limit - self.cursor
        if not self.out_grouping_b(DutchPorterStemmer.g_v):
            return False
        self.cursor = self.limit - v_1
        self.slice_del()
        self.B_e_found = True
        return self.__r_undouble()

    def __r_en_ending(self):
        if not self.__r_R1():
            return False
        v_1 = self.limit - self.cursor
        if not self.out_grouping_b(DutchPorterStemmer.g_v):
            return False
        self.cursor = self.limit - v_1
        try:
            if not self.eq_s_b("gem"):
                raise lab0()
            return False
        except lab0: pass
        self.slice_del()
        return self.__r_undouble()

    def __r_standard_suffix(self):
        v_1 = self.limit - self.cursor
        try:
            self.ket = self.cursor
            among_var = self.find_among_b(DutchPorterStemmer.a_3)
            if among_var == 0:
                raise lab0()
            self.bra = self.cursor
            if among_var == 1:
                if not self.__r_R1():
                    raise lab0()
                self.slice_from("heid")
            elif among_var == 2:
                if not self.__r_en_ending():
                    raise lab0()
            else:
                if not self.__r_R1():
                    raise lab0()
                if not self.out_grouping_b(DutchPorterStemmer.g_v_j):
                    raise lab0()
                self.slice_del()
        except lab0: pass
        self.cursor = self.limit - v_1
        v_2 = self.limit - self.cursor
        self.__r_e_ending()
        self.cursor = self.limit - v_2
        v_3 = self.limit - self.cursor
        try:
            self.ket = self.cursor
            if not self.eq_s_b("heid"):
                raise lab0()
            self.bra = self.cursor
            if not self.__r_R2():
                raise lab0()
            try:
                if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "c":
                    raise lab1()
                self.cursor -= 1
                raise lab0()
            except lab1: pass
            self.slice_del()
            self.ket = self.cursor
            if not self.eq_s_b("en"):
                raise lab0()
            self.bra = self.cursor
            if not self.__r_en_ending():
                raise lab0()
        except lab0: pass
        self.cursor = self.limit - v_3
        v_4 = self.limit - self.cursor
        try:
            self.ket = self.cursor
            among_var = self.find_among_b(DutchPorterStemmer.a_4)
            if among_var == 0:
                raise lab0()
            self.bra = self.cursor
            if among_var == 1:
                if not self.__r_R2():
                    raise lab0()
                self.slice_del()
                while True:
                    v_5 = self.limit - self.cursor
                    try:
                        self.ket = self.cursor
                        if not self.eq_s_b("ig"):
                            raise lab1()
                        self.bra = self.cursor
                        if not self.__r_R2():
                            raise lab1()
                        try:
                            if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "e":
                                raise lab2()
                            self.cursor -= 1
                            raise lab1()
                        except lab2: pass
                        self.slice_del()
                        break
                    except lab1: pass
                    self.cursor = self.limit - v_5
                    if not self.__r_undouble():
                        raise lab0()
                    break
            elif among_var == 2:
                if not self.__r_R2():
                    raise lab0()
                try:
                    if self.cursor <= self.limit_backward or self.current[self.cursor - 1] != "e":
                        raise lab1()
                    self.cursor -= 1
                    raise lab0()
                except lab1: pass
                self.slice_del()
            elif among_var == 3:
                if not self.__r_R2():
                    raise lab0()
                self.slice_del()
                if not self.__r_e_ending():
                    raise lab0()
            elif among_var == 4:
                if not self.__r_R2():
                    raise lab0()
                self.slice_del()
            else:
                if not self.__r_R2():
                    raise lab0()
                if not self.B_e_found:
                    raise lab0()
                self.slice_del()
        except lab0: pass
        self.cursor = self.limit - v_4
        v_6 = self.limit - self.cursor
        try:
            if not self.out_grouping_b(DutchPorterStemmer.g_v_I):
                raise lab0()
            v_7 = self.limit - self.cursor
            if self.find_among_b(DutchPorterStemmer.a_5) == 0:
                raise lab0()
            if not self.out_grouping_b(DutchPorterStemmer.g_v):
                raise lab0()
            self.cursor = self.limit - v_7
            self.ket = self.cursor
            if self.cursor <= self.limit_backward:
                raise lab0()
            self.cursor -= 1
            self.bra = self.cursor
            self.slice_del()
        except lab0: pass
        self.cursor = self.limit - v_6
        return True

    def _stem(self):
        v_1 = self.cursor
        self.__r_prelude()
        self.cursor = v_1
        v_2 = self.cursor
        self.__r_mark_regions()
        self.cursor = v_2
        self.limit_backward = self.cursor
        self.cursor = self.limit
        self.__r_standard_suffix()
        self.cursor = self.limit_backward
        v_3 = self.cursor
        self.__r_postlude()
        self.cursor = v_3
        return True

    a_0 = [
        Among("", -1, 6),
        Among("á", 0, 1),
        Among("ä", 0, 1),
        Among("é", 0, 2),
        Among("ë", 0, 2),
        Among("í", 0, 3),
        Among("ï", 0, 3),
        Among("ó", 0, 4),
        Among("ö", 0, 4),
        Among("ú", 0, 5),
        Among("ü", 0, 5)
    ]

    a_1 = [
        Among("", -1, 3),
        Among("I", 0, 2),
        Among("Y", 0, 1)
    ]

    a_2 = [
        Among("dd", -1, -1),
        Among("kk", -1, -1),
        Among("tt", -1, -1)
    ]

    a_3 = [
        Among("ene", -1, 2),
        Among("se", -1, 3),
        Among("en", -1, 2),
        Among("heden", 2, 1),
        Among("s", -1, 3)
    ]

    a_4 = [
        Among("end", -1, 1),
        Among("ig", -1, 2),
        Among("ing", -1, 1),
        Among("lijk", -1, 3),
        Among("baar", -1, 4),
        Among("bar", -1, 5)
    ]

    a_5 = [
        Among("aa", -1, -1),
        Among("ee", -1, -1),
        Among("oo", -1, -1),
        Among("uu", -1, -1)
    ]


class lab0(BaseException): pass


class lab1(BaseException): pass


class lab2(BaseException): pass


class lab3(BaseException): pass



# Generated from armenian.sbl by Snowball 3.1.1 - https://snowballstem.org/

from .basestemmer import BaseStemmer
from .among import Among


class ArmenianStemmer(BaseStemmer):
    '''
    This class implements the stemming algorithm defined by a snowball script.
    Generated from armenian.sbl by Snowball 3.1.1 - https://snowballstem.org/
    '''

    g_v = {"ա", "ե", "է", "ը", "ի", "ո", "ւ", "օ"}

    I_p2 = 0
    I_pV = 0

    def __r_mark_regions(self):
        self.I_pV = self.limit
        self.I_p2 = self.limit
        v_1 = self.cursor
        try:
            if not self.go_out_grouping(ArmenianStemmer.g_v):
                raise lab0()
            self.cursor += 1
            self.I_pV = self.cursor
            if not self.go_in_grouping(ArmenianStemmer.g_v):
                raise lab0()
            self.cursor += 1
            if not self.go_out_grouping(ArmenianStemmer.g_v):
                raise lab0()
            self.cursor += 1
            if not self.go_in_grouping(ArmenianStemmer.g_v):
                raise lab0()
            self.cursor += 1
            self.I_p2 = self.cursor
        except lab0: pass
        self.cursor = v_1
        return True

    def __r_adjective(self):
        self.ket = self.cursor
        if self.find_among_b(ArmenianStemmer.a_0) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        return True

    def __r_verb(self):
        self.ket = self.cursor
        if self.find_among_b(ArmenianStemmer.a_1) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        return True

    def __r_noun(self):
        self.ket = self.cursor
        if self.find_among_b(ArmenianStemmer.a_2) == 0:
            return False
        self.bra = self.cursor
        self.slice_del()
        return True

    def __r_ending(self):
        self.ket = self.cursor
        if self.find_among_b(ArmenianStemmer.a_3) == 0:
            return False
        self.bra = self.cursor
        if self.I_p2 > self.cursor:
            return False
        self.slice_del()
        return True

    def _stem(self):
        self.__r_mark_regions()
        self.limit_backward = self.cursor
        self.cursor = self.limit
        if self.cursor < self.I_pV:
            return False
        v_2 = self.limit_backward
        self.limit_backward = self.I_pV
        v_3 = self.limit - self.cursor
        self.__r_ending()
        self.cursor = self.limit - v_3
        v_4 = self.limit - self.cursor
        self.__r_verb()
        self.cursor = self.limit - v_4
        v_5 = self.limit - self.cursor
        self.__r_adjective()
        self.cursor = self.limit - v_5
        v_6 = self.limit - self.cursor
        self.__r_noun()
        self.cursor = self.limit - v_6
        self.limit_backward = v_2
        self.cursor = self.limit_backward
        return True

    a_0 = [
        Among("րորդ", -1, 1),
        Among("երորդ", 0, 1),
        Among("ալի", -1, 1),
        Among("ակի", -1, 1),
        Among("որակ", -1, 1),
        Among("եղ", -1, 1),
        Among("ական", -1, 1),
        Among("արան", -1, 1),
        Among("են", -1, 1),
        Among("եկեն", 8, 1),
        Among("երեն", 8, 1),
        Among("որէն", -1, 1),
        Among("ին", -1, 1),
        Among("գին", 12, 1),
        Among("ովին", 12, 1),
        Among("լայն", -1, 1),
        Among("վուն", -1, 1),
        Among("պես", -1, 1),
        Among("իվ", -1, 1),
        Among("ատ", -1, 1),
        Among("ավետ", -1, 1),
        Among("կոտ", -1, 1),
        Among("բար", -1, 1)
    ]

    a_1 = [
        Among("ա", -1, 1),
        Among("ացա", 0, 1),
        Among("եցա", 0, 1),
        Among("վե", -1, 1),
        Among("ացրի", -1, 1),
        Among("ացի", -1, 1),
        Among("եցի", -1, 1),
        Among("վեցի", 6, 1),
        Among("ալ", -1, 1),
        Among("ըալ", 8, 1),
        Among("անալ", 8, 1),
        Among("ենալ", 8, 1),
        Among("ացնալ", 8, 1),
        Among("ել", -1, 1),
        Among("ըել", 13, 1),
        Among("նել", 13, 1),
        Among("ցնել", 15, 1),
        Among("եցնել", 16, 1),
        Among("չել", 13, 1),
        Among("վել", 13, 1),
        Among("ացվել", 19, 1),
        Among("եցվել", 19, 1),
        Among("տել", 13, 1),
        Among("ատել", 22, 1),
        Among("ոտել", 22, 1),
        Among("կոտել", 24, 1),
        Among("ված", -1, 1),
        Among("ում", -1, 1),
        Among("վում", 27, 1),
        Among("ան", -1, 1),
        Among("ցան", 29, 1),
        Among("ացան", 30, 1),
        Among("ացրին", -1, 1),
        Among("ացին", -1, 1),
        Among("եցին", -1, 1),
        Among("վեցին", 34, 1),
        Among("ալիս", -1, 1),
        Among("ելիս", -1, 1),
        Among("ավ", -1, 1),
        Among("ացավ", 38, 1),
        Among("եցավ", 38, 1),
        Among("ալով", -1, 1),
        Among("ելով", -1, 1),
        Among("ար", -1, 1),
        Among("ացար", 43, 1),
        Among("եցար", 43, 1),
        Among("ացրիր", -1, 1),
        Among("ացիր", -1, 1),
        Among("եցիր", -1, 1),
        Among("վեցիր", 48, 1),
        Among("աց", -1, 1),
        Among("եց", -1, 1),
        Among("ացրեց", 51, 1),
        Among("ալուց", -1, 1),
        Among("ելուց", -1, 1),
        Among("ալու", -1, 1),
        Among("ելու", -1, 1),
        Among("աք", -1, 1),
        Among("ցաք", 57, 1),
        Among("ացաք", 58, 1),
        Among("ացրիք", -1, 1),
        Among("ացիք", -1, 1),
        Among("եցիք", -1, 1),
        Among("վեցիք", 62, 1),
        Among("անք", -1, 1),
        Among("ցանք", 64, 1),
        Among("ացանք", 65, 1),
        Among("ացրինք", -1, 1),
        Among("ացինք", -1, 1),
        Among("եցինք", -1, 1),
        Among("վեցինք", 69, 1)
    ]

    a_2 = [
        Among("որդ", -1, 1),
        Among("ույթ", -1, 1),
        Among("ուհի", -1, 1),
        Among("ցի", -1, 1),
        Among("իլ", -1, 1),
        Among("ակ", -1, 1),
        Among("յակ", 5, 1),
        Among("անակ", 5, 1),
        Among("իկ", -1, 1),
        Among("ուկ", -1, 1),
        Among("ան", -1, 1),
        Among("պան", 10, 1),
        Among("ստան", 10, 1),
        Among("արան", 10, 1),
        Among("եղէն", -1, 1),
        Among("յուն", -1, 1),
        Among("ություն", 15, 1),
        Among("ածո", -1, 1),
        Among("իչ", -1, 1),
        Among("ուս", -1, 1),
        Among("ուստ", -1, 1),
        Among("գար", -1, 1),
        Among("վոր", -1, 1),
        Among("ավոր", 22, 1),
        Among("ոց", -1, 1),
        Among("անօց", -1, 1),
        Among("ու", -1, 1),
        Among("ք", -1, 1),
        Among("չեք", 27, 1),
        Among("իք", 27, 1),
        Among("ալիք", 29, 1),
        Among("անիք", 29, 1),
        Among("վածք", 27, 1),
        Among("ույք", 27, 1),
        Among("ենք", 27, 1),
        Among("ոնք", 27, 1),
        Among("ունք", 27, 1),
        Among("մունք", 36, 1),
        Among("իչք", 27, 1),
        Among("արք", 27, 1)
    ]

    a_3 = [
        Among("սա", -1, 1),
        Among("վա", -1, 1),
        Among("ամբ", -1, 1),
        Among("դ", -1, 1),
        Among("անդ", 3, 1),
        Among("ությանդ", 4, 1),
        Among("վանդ", 4, 1),
        Among("ոջդ", 3, 1),
        Among("երդ", 3, 1),
        Among("ներդ", 8, 1),
        Among("ուդ", 3, 1),
        Among("ը", -1, 1),
        Among("անը", 11, 1),
        Among("ությանը", 12, 1),
        Among("վանը", 12, 1),
        Among("ոջը", 11, 1),
        Among("երը", 11, 1),
        Among("ները", 16, 1),
        Among("ի", -1, 1),
        Among("վի", 18, 1),
        Among("երի", 18, 1),
        Among("ների", 20, 1),
        Among("անում", -1, 1),
        Among("երում", -1, 1),
        Among("ներում", 23, 1),
        Among("ն", -1, 1),
        Among("ան", 25, 1),
        Among("ության", 26, 1),
        Among("վան", 26, 1),
        Among("ին", 25, 1),
        Among("երին", 29, 1),
        Among("ներին", 30, 1),
        Among("ությանն", 25, 1),
        Among("երն", 25, 1),
        Among("ներն", 33, 1),
        Among("ուն", 25, 1),
        Among("ոջ", -1, 1),
        Among("ությանս", -1, 1),
        Among("վանս", -1, 1),
        Among("ոջս", -1, 1),
        Among("ով", -1, 1),
        Among("անով", 40, 1),
        Among("վով", 40, 1),
        Among("երով", 40, 1),
        Among("ներով", 43, 1),
        Among("եր", -1, 1),
        Among("ներ", 45, 1),
        Among("ց", -1, 1),
        Among("ից", 47, 1),
        Among("վանից", 48, 1),
        Among("ոջից", 48, 1),
        Among("վից", 48, 1),
        Among("երից", 48, 1),
        Among("ներից", 52, 1),
        Among("ցից", 48, 1),
        Among("ոց", 47, 1),
        Among("ուց", 47, 1)
    ]


class lab0(BaseException): pass



# Generated from hungarian.sbl by Snowball 3.1.1 - https://snowballstem.org/

from .basestemmer import BaseStemmer
from .among import Among


class HungarianStemmer(BaseStemmer):
    '''
    This class implements the stemming algorithm defined by a snowball script.
    Generated from hungarian.sbl by Snowball 3.1.1 - https://snowballstem.org/
    '''

    g_v = {"a", "e", "i", "o", "u", "á", "é", "í", "ó", "ö", "ú", "ü", "ő", "ű"}

    I_p1 = 0

    def __r_mark_regions(self):
        self.I_p1 = self.limit
        while True:
            v_1 = self.cursor
            try:
                if not self.in_grouping(HungarianStemmer.g_v):
                    raise lab0()
                v_2 = self.cursor
                try:
                    if not self.go_in_grouping(HungarianStemmer.g_v):
                        raise lab1()
                    self.cursor += 1
                    self.I_p1 = self.cursor
                except lab1: pass
                self.cursor = v_2
                break
            except lab0: pass
            self.cursor = v_1
            if not self.go_out_grouping(HungarianStemmer.g_v):
                return False
            self.cursor += 1
            self.I_p1 = self.cursor
            break
        return True

    def __r_R1(self):
        return self.I_p1 <= self.cursor

    def __r_v_ending(self):
        self.ket = self.cursor
        among_var = self.find_among_b(HungarianStemmer.a_0)
        if among_var == 0:
            return False
        self.bra = self.cursor
        if not self.__r_R1():
            return False
        self.slice_from(HungarianStemmer.as_0[among_var - 1])
        return True

    def __r_double(self):
        v_1 = self.limit - self.cursor
        if self.find_among_b(HungarianStemmer.a_1) == 0:
            return False
        self.cursor = self.limit - v_1
        return True

    def __r_undouble(self):
        if self.cursor <= self.limit_backward:
            return False
        self.cursor -= 1
        self.ket = self.cursor
        if self.cursor <= self.limit_backward:
            return False
        self.cursor -= 1
        self.bra = self.cursor
        self.slice_del()
        return True

    def __r_instrum(self):
        self.ket = self.cursor
        if self.find_among_b(HungarianStemmer.a_2) == 0:
            return False
        self.bra = self.cursor
        if not self.__r_R1():
            return False
        if not self.__r_double():
            return False
        self.slice_del()
        return self.__r_undouble()

    def __r_case(self):
        self.ket = self.cursor
        if self.find_among_b(HungarianStemmer.a_3) == 0:
            return False
        self.bra = self.cursor
        if not self.__r_R1():
            return False
        self.slice_del()
        return self.__r_v_ending()

    def __r_case_special(self):
        self.ket = self.cursor
        among_var = self.find_among_b(HungarianStemmer.a_4)
        if among_var == 0:
            return False
        self.bra = self.cursor
        if not self.__r_R1():
            return False
        self.slice_from(HungarianStemmer.as_4[among_var - 1])
        return True

    def __r_case_other(self):
        self.ket = self.cursor
        among_var = self.find_among_b(HungarianStemmer.a_5)
        if among_var == 0:
            return False
        self.bra = self.cursor
        if not self.__r_R1():
            return False
        self.slice_from(HungarianStemmer.as_5[among_var - 1])
        return True

    def __r_factive(self):
        self.ket = self.cursor
        if self.find_among_b(HungarianStemmer.a_6) == 0:
            return False
        self.bra = self.cursor
        if not self.__r_R1():
            return False
        if not self.__r_double():
            return False
        self.slice_del()
        return self.__r_undouble()

    def __r_plural(self):
        self.ket = self.cursor
        among_var = self.find_among_b(HungarianStemmer.a_7)
        if among_var == 0:
            return False
        self.bra = self.cursor
        if not self.__r_R1():
            return False
        self.slice_from(HungarianStemmer.as_7[among_var - 1])
        return True

    def __r_owned(self):
        self.ket = self.cursor
        among_var = self.find_among_b(HungarianStemmer.a_8)
        if among_var == 0:
            return False
        self.bra = self.cursor
        if not self.__r_R1():
            return False
        self.slice_from(HungarianStemmer.as_8[among_var - 1])
        return True

    def __r_sing_owner(self):
        self.ket = self.cursor
        among_var = self.find_among_b(HungarianStemmer.a_9)
        if among_var == 0:
            return False
        self.bra = self.cursor
        if not self.__r_R1():
            return False
        self.slice_from(HungarianStemmer.as_9[among_var - 1])
        return True

    def __r_plur_owner(self):
        self.ket = self.cursor
        among_var = self.find_among_b(HungarianStemmer.a_10)
        if among_var == 0:
            return False
        self.bra = self.cursor
        if not self.__r_R1():
            return False
        self.slice_from(HungarianStemmer.as_10[among_var - 1])
        return True

    def _stem(self):
        v_1 = self.cursor
        self.__r_mark_regions()
        self.cursor = v_1
        self.limit_backward = self.cursor
        self.cursor = self.limit
        v_2 = self.limit - self.cursor
        self.__r_instrum()
        self.cursor = self.limit - v_2
        v_3 = self.limit - self.cursor
        self.__r_case()
        self.cursor = self.limit - v_3
        v_4 = self.limit - self.cursor
        self.__r_case_special()
        self.cursor = self.limit - v_4
        v_5 = self.limit - self.cursor
        self.__r_case_other()
        self.cursor = self.limit - v_5
        v_6 = self.limit - self.cursor
        self.__r_factive()
        self.cursor = self.limit - v_6
        v_7 = self.limit - self.cursor
        self.__r_owned()
        self.cursor = self.limit - v_7
        v_8 = self.limit - self.cursor
        self.__r_sing_owner()
        self.cursor = self.limit - v_8
        v_9 = self.limit - self.cursor
        self.__r_plur_owner()
        self.cursor = self.limit - v_9
        v_10 = self.limit - self.cursor
        self.__r_plural()
        self.cursor = self.limit - v_10
        self.cursor = self.limit_backward
        return True

    a_0 = [
        Among("á", -1, 1),
        Among("é", -1, 2)
    ]
    as_0 = ("a", "e")

    a_1 = [
        Among("bb", -1, -1),
        Among("cc", -1, -1),
        Among("dd", -1, -1),
        Among("ff", -1, -1),
        Among("gg", -1, -1),
        Among("jj", -1, -1),
        Among("kk", -1, -1),
        Among("ll", -1, -1),
        Among("mm", -1, -1),
        Among("nn", -1, -1),
        Among("pp", -1, -1),
        Among("rr", -1, -1),
        Among("ccs", -1, -1),
        Among("ss", -1, -1),
        Among("zzs", -1, -1),
        Among("tt", -1, -1),
        Among("vv", -1, -1),
        Among("ggy", -1, -1),
        Among("lly", -1, -1),
        Among("nny", -1, -1),
        Among("tty", -1, -1),
        Among("ssz", -1, -1),
        Among("zz", -1, -1)
    ]

    a_2 = [
        Among("al", -1, 1),
        Among("el", -1, 1)
    ]

    a_3 = [
        Among("ba", -1, -1),
        Among("ra", -1, -1),
        Among("be", -1, -1),
        Among("re", -1, -1),
        Among("ig", -1, -1),
        Among("nak", -1, -1),
        Among("nek", -1, -1),
        Among("val", -1, -1),
        Among("vel", -1, -1),
        Among("ul", -1, -1),
        Among("nál", -1, -1),
        Among("nél", -1, -1),
        Among("ból", -1, -1),
        Among("ról", -1, -1),
        Among("tól", -1, -1),
        Among("ül", -1, -1),
        Among("ből", -1, -1),
        Among("ről", -1, -1),
        Among("től", -1, -1),
        Among("n", -1, -1),
        Among("an", 19, -1),
        Among("ban", 20, -1),
        Among("en", 19, -1),
        Among("ben", 22, -1),
        Among("képpen", 22, -1),
        Among("on", 19, -1),
        Among("ön", 19, -1),
        Among("képp", -1, -1),
        Among("kor", -1, -1),
        Among("t", -1, -1),
        Among("at", 29, -1),
        Among("et", 29, -1),
        Among("ként", 29, -1),
        Among("anként", 32, -1),
        Among("enként", 32, -1),
        Among("onként", 32, -1),
        Among("ot", 29, -1),
        Among("ért", 29, -1),
        Among("öt", 29, -1),
        Among("hez", -1, -1),
        Among("hoz", -1, -1),
        Among("höz", -1, -1),
        Among("vá", -1, -1),
        Among("vé", -1, -1)
    ]

    a_4 = [
        Among("án", -1, 2),
        Among("én", -1, 1),
        Among("ánként", -1, 2)
    ]
    as_4 = ("e", "a")

    a_5 = [
        Among("stul", -1, 1),
        Among("astul", 0, 1),
        Among("ástul", 0, 2),
        Among("stül", -1, 1),
        Among("estül", 3, 1),
        Among("éstül", 3, 3)
    ]
    as_5 = ("", "a", "e")

    a_6 = [
        Among("á", -1, 1),
        Among("é", -1, 1)
    ]

    a_7 = [
        Among("k", -1, 3),
        Among("ak", 0, 3),
        Among("ek", 0, 3),
        Among("ok", 0, 3),
        Among("ák", 0, 1),
        Among("ék", 0, 2),
        Among("ök", 0, 3)
    ]
    as_7 = ("a", "e", "")

    a_8 = [
        Among("éi", -1, 1),
        Among("áéi", 0, 3),
        Among("ééi", 0, 2),
        Among("é", -1, 1),
        Among("ké", 3, 1),
        Among("aké", 4, 1),
        Among("eké", 4, 1),
        Among("oké", 4, 1),
        Among("áké", 4, 3),
        Among("éké", 4, 2),
        Among("öké", 4, 1),
        Among("éé", 3, 2)
    ]
    as_8 = ("", "e", "a")

    a_9 = [
        Among("a", -1, 1),
        Among("ja", 0, 1),
        Among("d", -1, 1),
        Among("ad", 2, 1),
        Among("ed", 2, 1),
        Among("od", 2, 1),
        Among("ád", 2, 2),
        Among("éd", 2, 3),
        Among("öd", 2, 1),
        Among("e", -1, 1),
        Among("je", 9, 1),
        Among("nk", -1, 1),
        Among("unk", 11, 1),
        Among("ánk", 11, 2),
        Among("énk", 11, 3),
        Among("ünk", 11, 1),
        Among("uk", -1, 1),
        Among("juk", 16, 1),
        Among("ájuk", 17, 2),
        Among("ük", -1, 1),
        Among("jük", 19, 1),
        Among("éjük", 20, 3),
        Among("m", -1, 1),
        Among("am", 22, 1),
        Among("em", 22, 1),
        Among("om", 22, 1),
        Among("ám", 22, 2),
        Among("ém", 22, 3),
        Among("o", -1, 1),
        Among("á", -1, 2),
        Among("é", -1, 3)
    ]
    as_9 = ("", "a", "e")

    a_10 = [
        Among("id", -1, 1),
        Among("aid", 0, 1),
        Among("jaid", 1, 1),
        Among("eid", 0, 1),
        Among("jeid", 3, 1),
        Among("áid", 0, 2),
        Among("éid", 0, 3),
        Among("i", -1, 1),
        Among("ai", 7, 1),
        Among("jai", 8, 1),
        Among("ei", 7, 1),
        Among("jei", 10, 1),
        Among("ái", 7, 2),
        Among("éi", 7, 3),
        Among("itek", -1, 1),
        Among("eitek", 14, 1),
        Among("jeitek", 15, 1),
        Among("éitek", 14, 3),
        Among("ik", -1, 1),
        Among("aik", 18, 1),
        Among("jaik", 19, 1),
        Among("eik", 18, 1),
        Among("jeik", 21, 1),
        Among("áik", 18, 2),
        Among("éik", 18, 3),
        Among("ink", -1, 1),
        Among("aink", 25, 1),
        Among("jaink", 26, 1),
        Among("eink", 25, 1),
        Among("jeink", 28, 1),
        Among("áink", 25, 2),
        Among("éink", 25, 3),
        Among("aitok", -1, 1),
        Among("jaitok", 32, 1),
        Among("áitok", -1, 2),
        Among("im", -1, 1),
        Among("aim", 35, 1),
        Among("jaim", 36, 1),
        Among("eim", 35, 1),
        Among("jeim", 38, 1),
        Among("áim", 35, 2),
        Among("éim", 35, 3)
    ]
    as_10 = ("", "a", "e")


class lab0(BaseException): pass


class lab1(BaseException): pass
